(function (root, factory) {
    if (typeof define === 'function' && define.amd) {
        // AMD. Register as an anonymous module.
        define(['exports', 'echarts'], factory);
    } else if (typeof exports === 'object' && typeof exports.nodeName !== 'string') {
        // CommonJS
        factory(exports, require('echarts'));
    } else {
        // Browser globals
        factory({}, root.echarts);
    }
}(this, function (exports, echarts) {
    var log = function (msg) {
        if (typeof console !== 'undefined') {
            console && console.error && console.error(msg);
        }
    }
    if (!echarts) {
        log('ECharts is not Loaded');
        return;
    }
    if (!echarts.registerMap) {
        log('ECharts Map is not loaded')
        return;
    }
    echarts.registerMap('云南', {"type":"FeatureCollection","features":[{"id":"530100","type":"Feature","geometry":{"type":"Polygon","coordinates":["@@FKCQEGAGDIBQBCHIFMBCCEFADG@G@OHQ@EHIAGBO@OBCDCACBEAINc@MHO@OFEHS@GBKAC@EFG@GAAEAAEAUBIDELGFOFCAEFE@CECDEEICOAE@IDGCGJGPEFIRIJ@NHJ@BGCYBIFELATADC@CEC@ALODKFEHANDDFIL@FJNL@JEP@H@PMHKRGJINI@GBCNGDEBCEEGGAIGCG@CC@CRETO@CBQEIAMFKFGLIDGDW@CHBJGJICGBAJ@BGFIRI@CNQ@IIKISOWKc@ICEBIFGBEBAFA\\@BEACMAIEBEHEBGEAE@CAAM@EDGFCXE@@AKCKBCEMDEHI@CGEAGA@FKBCIAA@ABC@EEEK@KDQDENEBCAAMAAA@ADEGC@ETDHCPKI@EEN@BABG@ADDDABCFBDDPJBFIJDDVBRAFEJEDIHA\\RHDV@@EGKAI@EJIVITAPBFD`VFJBFAFBDHDBHF@J@H@FHLEBEHC@KDO@KACIKCG@CJKHCD@ZVFBLGDBCH@HJEBOF@BACODGFCHAHBFDFFLDFHRBHGDGAGKG@EDCHCFELMDEAIUSCECAO@CASSIA@GGGAAFOBCRIDIHI@AMODG@COCEAII@AHE@GEAJIBICEGEAGIQEESKCMFKGQBOXOBQTCPJH@LIBCAGDAHAJQHGSECE@KY@IDA@WUKCOIQCcDEHKDM@OPKPGDI@E@EGCGBCLGJSFEBEAEKOMMAGBILEDELG@A@GGG@MACGCBOCEEAKJGBMBCCCIEAC@GLA@E@KFCAGGGCAD@FABGMGABE@GIC@@@AHC@A@IHEFIDE@CMIICGGMG@A@IKMWKw]GGAOIGAE@KKMAEAEGAECACBEAII[H@DDJ@DABE@ILKFCJAFDFBN@NCBC@ACECKCAECE@CBA@AIFC@EG[KIK@CGAKFEFIBICAMBGEQ@AIIS@GO[CQFAH@BCLABADADBRKBBDDVGEABCAABIICACECBKNCHGN@HGBQBGAECCCG@GFEHCRKD@BLDLAL@JBBJFHBbCb@N@NGLQJE@HBBD@LEDB@DCHDBBBIHFFD^HDHBFLDBH@FETG@FNBFKJAJBBA@AFAB@DDFBBKDEDMIQCEbY@CACKE@EGM@EDGDCP@HARODE@QEGECC@GDK@KEIEGIGGCEEAODK@eG[S@]BCFCN@NEJIBCDALGDCBE@AEACA@CFCPE@MBCFCRGAGJG@EFIBQDCNA@CCADC@ASICC@IBOAEBKE@IQEACAEAKBCGJEFI@GAE@QEO@CLGPGDGHU\\IBEAM@EBAD@HIEKBAB@FBDBJEBGHBDAJBPABCFBF@AJD@HAFBFJDHDFF^FDHBFADCFIDCLCFINAFBDjH\\LNRBHABEBMDEP@\\NZBLCHCNKFMCcG_BWRWFO@M@ICEOQFIHKBEBENG@CACK]IM@CLKDEAACKKMCQGIEIECKYECGS@CBCNIAKEGSKEOIK@EVGBG@IGMIGIIaUGGCGOEEKECQEECEIEAiACGBGACBGACCCGSKKQCCIGJOFCACOOKIEaKE@@HKJWFAH@BFDN@TDXVBF@DCBMFGD@D@DHJ\\HDDABABQ@SDUCABCFCBMB@DFFCDKAEAE@SFKFEDEH@DQPEDE@IJE@KJCFE@CAM@SN@FADODK@E@@DDD@BABMLSJAD@DCBKB@DDBADABIBAAAECCECE@CDKJMRIDGBECAC@MBC@GOCCACIBEHCLAFEBCEI@CBC@OGC_HEAAKBUCEMEAC@AJCJWBKDM@EEIMIKCCEGEGEAKBAFBBAACCAAEDALCDC@CACECKAQFSBCBCRC@IEOB@D@LADCBIEGKEAGDCDG@EMCAGFC@ACHGACGAGHCPILKDEAIEKWCCGHIBMEMMADAVBHFL@LBJ@NBRAJDDADEBSEGGG@IKI@E@KHKCGBSAGHGPGBBH@FEHBDHH@FEJDTGD@DABEBBJEH@FD@BBAH@JGVB\\DHBJDFAFFT@LJP@H@DFFLBBHFFHTDL@FFF@HDD@HHNBHFHGLKFG@QAQRCBEAGMEEEEGGGDIFEFCNDL@XDNAFLDDDAZJ\\CLEHFHBDDT@JDNGTALIRERQNCRIPA@AoGOGESGOFADEDECCBAA@QACAEEKCABIE@KDCAI@KE@OCAIH@MEGC@ADBLCD@HCDEDCAKKCQAYNC@AGEKCACASCCDG@IHEFKAQBALEDCACGE@CBI@AAAK@OEAMGAACM@CCAKCKKGE@@BCPABCBIBGBg@CI@CFEDMJKJOHWEOKSOGCCGMIGAAAWIM@UAEEGECQCCA@CDCLK@KDGACIAAGGEDEACKAAC@OFC@EKaMUAG@IHCBCGI@CDCLGDG@EPKN@FA@CUGMGI@ACCKICG@GFC@KKCIEKAEKIG@K@CB@DDD@JKFM@AACKEASMI@]EIKCBEHC@KJANABADBLHBDD[XEB_@GCCGCAO@MASGO@C@GBMNKACDKDABBDJFLDLBJFEDODFHAJCF@JIFKDUIOBIFAAIIOICGECI@CABOE@K@MFEFI@ADBFFDH@BDADCBUEEGAC@CECGSGCMKOAIFED@HGAODQJGASA@EHIBE@CIEUS@ECEMEEAEBC@EA@@@RGJALCBGCIBE@MQGKC]@KISECWGEEBKFEF@NDH@@GAAGBECCOCGAGBGDEBCCAEKGACFEBG@ICM@UMICCC@CECEBGLILEBGBAHEFPHLJ@BGJAFCDGFIAEBKJKDM@IDEFE@QCABDH@DMZEHWNY\\QC@DGLCXINBDZCBFTLPPBF`FJFDH@JBFNBHDDFFHGFDFHCDADAJBHDJXLHDbGJALAVCJBFCHY^KVBFBDZ@LFFFMRAVCNHDDLFDBNGFAHHJFrBRFF@DKRAPFJADIFCD@PADBDAFBDAFTD@TELIJDB@BHH@BBBDBABBBENFPKFCFBFF@FD@BIHCDBHDJBFGFI@G@ECC@QLEHAHEP@HDFFHBLCFGBGAIASMGCIBIC@DEDCF@JDNLR@FRRDFBHDH@BDHFDCDAFFLALIDM@EBCBEJBFDDCHQCCC]IIBMHCJ@JADEFKLABFNBFAZCDEBEFEN@D@DHJDLRNDF@D@HFDV@BCAK@GCMDEHGHALDD@NCTO@IGSBAHEN@VDZLRNPBFJJFZXF@JCFENAJ@FAPBFADCD@BB@DFHDDDBBBAJDJBDCPJRDDHBDNFH@FIJBP@XAHCFMCABADPLJVDRPfZ^FJBBDAPEL@DBIH@NJNJF@FFV@HCHQR@RDN@FG@_MIAG@GFCHBnKNILAHDTBFFFBJQFGJKHABBFTHBD@JEPTbFDN@FIRIBOHELAJ@NHP@`TBDCHFD@FIHAF@DDDFBBA@CBADJNBDFFHDBJDAD@XDBDHHLHDBDEN@DDDTAARH\\CREL[NEHAHDJANFREFMBKJAFDLCHDHCNDBJFDRAREDE@UEMKCBINEPGDGAG@ONCFCPCDS@GDADC\\CJEFMACD@FFRLLLRA^@HJXIL[VQRENEF@ZBFNHBB@NAP@T@FHPFBTBFBBDGLAJBHGABHFHHVCRKLKHKFOLIBY@KJ@FBNER@NGH@LPTP@BBKFGJ@DCD@TBDHDLDDDBLIJWHCD@TFDGPBFLPNZBJANEJBFFDBDAH@BHFFJBFCLFPAF@DFDDD@FAHCDBBJBDBILAF@LCDSLKBEAE@KHGBCFCNGFKHCFMFKDONMDKFEDEB@DFFADBRGLUP@REH@FCFKLAF@BJHBDDLB`DFTJNBTAX@RDNHZBFJZJJBPJNDDBXZLRRRJPDLRNFBN@DBVDbALBdNXJHB\\LPJXBJDlLRHFHDNBTFFFD^DJATMZMVCLEVARMDIFQDIDO@GCCMIeaCMC]GKCI@ARGX@DIVMPGVGJEBCDEDOPGLAVFVLF@DGN@NFDDDFDLA^DJPZPLDHAFBBPFPBLBHJJRFFPJHF`HH@NDZ@RDB@FLPHLHHPPLJJFTJNJTD@FIJE@EEK@EHKHCXFX@DANKHFZF\\@dBTJLN@NDLLL@DELGdEP@PDPBXFRFNBFARM\\AP@DZDZCL@LFJBV\\@LDLPDHTBHE\\HAHK"],"encodeOffsets":[[105536,27172]]},"properties":{"cp":[102.712251,25.040609],"name":"昆明市","childNum":1}},{"id":"530300","type":"Feature","geometry":{"type":"MultiPolygon","coordinates":[["@@IAABBJLN@LCHEFKDIHCHIJCJBJLLHVBPPNDTHXGN@DRPFFHNBNDHFBAHBB@TCDSFCF@DDFHAFCVADFDD@JFXDFLHDFDJBHDHDNBNGN@DLL@JMTEFKHMDADDHJHDEHAHADAFGPMHAL@FBBDD@PJFBDBLRDBLAJBD@FABGDCTILCNBNNRBPBJFVEJEBKBAREbCFBVBFDDF@HAJBFHBJ@PLDBHAZRHBDFAJBDTNLRFFB@P@L@bCJIBGBEPKFGPOBEAGDMDETUFQLUBGAK\\QNEHK@IAKWeCSHMBUHKLGDICACIGEC@O@MCCEMAECYCICGE@CDMAGMMCAG@EA@A@CACAMEEBMDYFCFQHIDCFG@EASBEJGAGBOLMJGBEJAHCFABBHHHHJHHAFE@EFI@CBI@CISBKAGIGGI@CBSCWFIAEBQOUGQAIDEVOHOJEAEDGCGCC@EEA@CB@FELEJGPEJABCF@@CH@DCD@AEF@HIBEJABAEEBCAC@GFE@KBBJCAAAB@ABCFBDAJBF@HDB@D@DAD@FEFIDALAFGBABEFADBB@JBDBH@LDJ@DCF@B@DALBZCRHnFNDPCTGLDLCJDJDJBDAHKHCL@ZD`@FCFIH@FBDDJDDDDBBAFHFD@BBD@BC@@D@PCJBFCFBFEHALAFBHHJ@DA@@HFDBAJHFDDDBDFBBHFDBDFDADFDBHNF@F@HHFBDDFF@ADFJJTPLZCPBFHL@F@HGHCJKLBHAFFJ@BA@EFABCPIDAFBPCLGHBJCDHLHDAFBNAHEFIDBLCF@FDDBBH@P@BTBPARENM@Q@ALAFBB@HBBDD@JFL@HBFAHBHABDHAFHFLFBBDAFFPDBF@DDH@HDDJABDDAFAHJNFB@HFDBFLLANDFCLBF@FBBBBL@BDFBD@HEJFFGAGBCF@DEJCBG@CHCFEDIEIBCBEHEVK@EFABKJABA@EBGEM@CCEBCEEAIAABGAIAEBE@IJOHGNKD@PKF@NJBFLDH@FEFBN@HAR@JAHBHCFDF@BFJBTIBCLIBE@AAKFAJ@@IDKGIGKCKECAKDOFALD^EFEF@JEFGLGD@FKFC@GTODGHGDG@CAAESCCACBQBCFEFKFEHAHBJCF@PEAGBE@KACFMDIIK@GJK@GDCTOFAACBKACEGCAC@KDCAOKCGAEBC@IBE@IACKAIE]CW@OK[COGEKIICGAC@IACIGIGCGWMScIGBS@CFMDMHCBAEIAIKAEECGDKAIKQAKGMOKCG@KAKBEAOBWHKHGBK@MCGBIOYECKCGCACBEAACEGCM@EFUHEFKDAFCDOCGQBILCDELOFK@IEKAQCEIAH]HKGGAMECAMBG@ACGGEQYAEEECG@M@CFADEAGKC@KCGIEGGI@GCGECG@GFOBMDCD@LJFBFCDCAQDABOHI@AYWK_BGFIHO@GEEMEIGI]GAIDBWGiCIM@K_CESUEAIAIHOJABBLC@ULKJEDCDA@AAEM@GFQ@EIGAC@ADICG@GD[EKAKEGAGBG@EEMBG@AKEACFYRGF@BABA@AKKEAEBAAJM\\WDKEG@CDGHCZDLAHBF@NGDECIBIEIAABAFBDHJFLDFFHJBBRCFEXIRANQBAACGIAGVQ@GCMHOCMDSI_YIDEJCJK@GAQLGF@FB@JD@HCDN@PBHBDFBDCF@D@XAX@JHJFLLH@HDFHDDDHBBBDFB@DBADBBDD@FE@CLABD@BFEDEH@FEB@@DADED@D@DDDBDFBNIBAGQFWIc@WCGIIAG@QDO@[C[IOBIBCFCJ@JKFAH@NRL@HCBGBALCRI@CCC@AFAFEDEBCZMFGNBJAJBHAHCLKEGFKDM@CCIBMAUJIDKCCUGAABE\\KF@JIF@JD@LDBT@RFNAHEDHHABB@GFCAQREXIHGDCZERB@DEDDFABADNBJ@LGJAFCR[HEH@HFLNL@HAJMNcACQCOCEKD[HSFGMM@C@CBGHIRO@CMG@EFCGICJOBIFMNOTOHGRQZKFKJEBEAGEEICAI@CAGKGE@GHALMBSAECGIEAGMOAWGCCGKEUSBECKASGIGGBICG@KBGICEGMGqIg@OAEC@ABAPBHCNARBRFTAHBLAFAPCHKNKLKAKJO@KDOLMBKMGC@GBECEEG@ECECAEBCFG@AOGKAGGIAAAAEBIAMACIEGGCA@C@GEIKKGKG]CCKEGEGCSAIIQGQWO[IE@ABGIMEEKCAGMKAEGAECAIKK@IDEGM@G@AHIAMJG@CIQ@IDE@GEGIECIGI@CBKSIAMGMAOKUGC@CAE@KCMGQOWUCEACCAGEEEACASHI@AGBCLCD@BADAACB@VFDHBLFBPADG@EBA^MDC@CC_BK@GCK@IHED[HGFKBMBG@GDODEAEHABABCFAD@FHB@BEJIDGLCBABGCKKAAEHIDQAEHEBEDGFGVGE@GIEQCECCKAI@I@ODEBCAAIBEHOAGE@GDMBGDIDYCQ@YGA@CHQAKGMCGCE@IG_IBK@GECG@ACFKLM@OKIG@U@QEW@UCIDOAQI@QGCaCMKCAMDIAMOE@QHKNOLIDI@GAEGAECAADEAIGOLC@U@AHKCEIC@EDEJBL@JTNRX@HCFEFGJGLOHUhOPEFEDCHEB]E_KI@ALGDEBGGKEYEgSG@[IeSO@C@EHELKFGNGBUJMDFND@FCF@@HGLOHCJBFAFBHBBHAFJJBPLH@FADBANBDJFGBFHER@NCBE@ECEBEH@D@HWdIJGBGIABAHAFEDINCJALYE@NCJBHDHN\\LDJDBFBDAFCFIB@FBHKBEDBHDH@HAFEFQHIAIGCIEUGCOD]T@FDDHBBB@NKLSJIBMAIGIAKBQH[ZC@GFIDMCCB@DLNBDA@QIM@CBUhIDGBCBCHEDBHGAC@ABKIICCD@FIB@DBD@BQOQWAM@OIACCBEIA]JMJONOHG@@DHNFRFFDHH@JMB@@PPLFRDRADABE@ECYUG@OF[@MOEG@EIEEAC@@FEDI@EACCGOIKCFKL@DJNFPFNBHMHAFAFGLEJPRDF@J@NEPQXAXH`DdENMLGDKDYA[MO@CFANAFGBQAKMG[CiEAMBEJKDCDEJCDEBGAECE]CECGEIEAGBC@BIE@EAADOBIACBGAAHIFCAEAA@ABFLGJC@AB@FBNAF[JGVCHOHKH@DFP@RBF@HEJIFDHLAFBDBFBJRF@ALBFAP@JDDTJ@BCDDB@DMBCDAREJ@FIHBHQHEDAD@NOFED@DDBFB@BAFCDKHCBADIJMFM@EDAD@^\\TfHL@PCFBDFHHHJJFLFL@HCD@FDFH@RCFQPGBO@CDCH@FHN@FLFBD@DaZDFJRCNCFALEACCA@EB@BABIAIBELMA@ESHEFG@CAEKGAGCC]EEJGAACADG@CCAKFC@AA@GIFKRMHM@a@aDGAIEAA@IBKCKAKC@QLGDEF@HDHDDBFAHARGHM@GHMDALFDBDJDAJBBADFBUHCCAAQLCACBABKBADG@EBDRP\\@HJTBJR@HFNADBAJEJEFBLDHL@LJH\\@FEDBJB@DAF@FDDBDLDF@BADMDM@EAECIBEDKL@JAFCBI@CCG@J\\BJAFBDFDHBBFBFLN@LBFJHBPHHx^XLLN@J@BNHHHJDNJ@DCFEJGF@J@BGD@B@@JD@HAFHBHNBA@EBCHDHHDBLEF@B@HKD@FBDJDDNAHALIFBDFAPHDBD@NHH@H@BKHCFKFAJBHNNLPBFAFEFITKHADDHFHF@J@HCLOPON@LCFGdCRDPJLDXVB@JCZ@@LDFTFGHIRGBCBBHADKJG@OISDARWPAPHRELDNTLFFJRBHHFDFAJIJFB@HGF@BJJFBPD@DCHNP@BGJCJQJADEPBBHH@HJBTTDBP@DBDFVTBHCHKNEFGDCD@FLHBHCHEFKBGAEGKCEEECGAGBEDCHDPABE@APIF@GDGCAKHEAYUC@GDIL@DDHJLBD@LCP@LGDAFKFEGG@I@E@AGGCACBEAEEI_UECOASBUJIJ@FBJHL@FU@GC[QGBCJIFEFQBUACCJIAEOICCEAADCBCC@BAHABM@FFJ@OLGDSC@FHDCF@BBBNBBBADMFCFCR@LFLFFD@BAB@JBADELB@BHHF@DGJCFFNADDLBL@@WFEDCH@FBNDBF@FBAHGFAFJFNBBDAF[@EBABAFEHAJDF@JLdPXJTJL@JMR@DQJEJAHI@ABDHIJIHGA@DCXCHKJEHELBNFJAR@DSPQF@DDDH@HDBJHHFFADCFMHAD@HMJIJQHGLONG@O@IFK@IM@EJKCEMCGBEFCLKP@BFD@DCDSBKBEFAJDZAHI@MGI@QJEJOFIHDHCH@JBFDPFJCFFD@DEFBFEDEPKHCHAL@PDHFBBB@HEH@FBDAL@HGTEF@PGP@NMdBJAFBDCDAD@PAPBHGJ@FGR@P@HCHEBDFADENGJCVCJBHFHDRELHCTFTBADCBQCI@EBCHAHBV@PBFHHDFEPBXCDC@CDBBZL@DGD@DDDFBNBHGFBJDXNFNALHBLFPANGJ@BERGD@PGNCDCDID@BCtNZRHFBFADGN@BFFH@BFDDJJANMP@DDDH@DDBB@FBFNRLH@DIHCFHZ@JJHH@VEJAHLHB\\@VEFBDDBNBBJGDKHEFAXMJCJ@FBTNHNLHNFL@FABCESBMJCLARCJEH@HDDFAHULAD@DFDDB@DIB@BLDJBHB@BQ@MCEFC@@ADC"],["@@DED@@AKAED@DJB"]],"encodeOffsets":[[[105872,27378]],[[105872,27378]]]},"properties":{"cp":[103.797851,25.501557],"name":"曲靖市","childNum":2}},{"id":"530400","type":"Feature","geometry":{"type":"MultiPolygon","coordinates":[["@@BBJ@FCDCCAO@GCCKIGICG@@DBDJHD@HFLLBB"],["@@BJHD@BGPBBV@FB@BEJAFDHFDDBLEF@XHTBLBHHJR\\DHAF@BDCH@FJLHBT@DBFPBRDJANKRAF@HHRHLNPJHCQJELMDMJCTBNGLCZUGSHO@YDIFGAQDGNQ@KFULKAMBICE@CDALAFC@GFGBKIOAALIDKKG@CDGFAHIDEAIJJHBBCJMHCR@LJL@DDLAFFJFDFBDFABEHBDFJFDDPBFBFAJFBFFF@HDNLZLP@FZbLHBFBBJJDLHDBFAJDHBLFDDH@FHDBHPVFBDDJHJBDBH@JGBEDE@ED@HBFCDEEEBCNAFCAEEAAEBCDAJ@D@HEFGPGXABAAEBCB@FBH@FG@EBAF@DFF@FGHAHABEHKHA@CHEBKC@CE@GDAF@LBLGF@DB@BCPFHHBBRDHDBD@TK^@CY_SCEDIDC@ACCMGCC@C@CB@NDHADGGUJGD@HBJNFBFA@EAKIGDEFBFPB@D@JED@XJJFFABCDAJCHBJLB@HIDCNEJFIDCJHDV@@BCJ@FBBJDVAFCJKFADDBJBFNDJNHDDBF@NIF@JDBFJFHLHBTLFBFFBFFH@TDJBFAFDFBL@@CB@BBBFBFJEFKDAFDFB@J@HBHL@FPDHH@DEFBFCJBXAFELKFYEC@CDANDFDDBHFF@FNHBD@FIH@DEBILEP@FDDJJDNDFADE@M@IAECBIEEO@KII@KJKBK@AB@DC@EEEA@BDB@DABEC@@DDDB@FCBCGA@@BDHD@FAFDCDGBFHGL@FADGDECK@EG@DADB@@BCFAIAAA@AD@DBBED@FEDBDAFDJCNINECCBIN@FDDHDDFBJAHMZG@AEACA@BJG@LFSHCBDFLFLNJAFDF@HCDEJ@HAD@BDDFBBD@HDD@HDDB@DBDEF@NEJ@NADOAGH@BBFJJBF@BOFKHC@CGD[ACI@E@MJ@DBF@JEBC@ABZbJFJCDCFDFPHH@PFBBA@GF@BJFBLJBBEBOCG@BFFDDF@DGLADBDJBJEH@EBAFGF@LIDQ@ABFXAFCHFHBFEFAFDBLBAFBF@FFB@FDJAFLJDDDBFDBHNFDC@CBCH@DBBFHHJL@JDHANDFBFJBBCD@BCBAHLBB@BEDFBFAD@BDBFEB@FFLDB@DCFC@AFGHCD@PENDRFDF@LGNBR@RCPGPCB@FJFBbAH@DJLJ@HIP@FJJRLHDFDLBHDLTJJBHBPCH@HFL@HJEDBBEJGLGLANIJABGGC@IDCFANBDCFKJANBRKZAHCT@HDDHJDJAHDTNJBHBHADE@CAGEGCE@GFOBGDCTOD@FDH@J@HEAECIAGDCJG@AECE@AEDELEEOFMAABCC@AA@AGG@ACAJIFK@SSCBEACBEACBC@ODCJEBCEIBOLQ@CEEAQEqGIBGHEAMECCKGCDMBUNQEEKEY@ACAELUZ]DGAEDIBUBKHICaKGIWGCIACBCBGDCEHEEGCEGCMAAE@ICGIE_EAEOOSKAEYDACJMDWHK@CRDZ[XMFGNY@CCGBARDF@FEJCN@LCLIFAJBHEDCBEHI@AKIOGFEBGHAFAJKHKFAFD@DDDJDVNN@JDH@FADEHBFLDBADCFAHBHDHDPFDHABB@HG@MCE@EFALFFXHFDJT@LD^V^F@JAHDDABKHI@Q@@FBD@FAFBNFDF@FVTJF@DAFGJ@FTBHBRIPCHB@GFCJEPBNLHDHTFD@DBDFHVFDABCACG@ECAEBCJ@FENEL@F@APDBJ@FDDHPJJJBBJEPAVJLCJE@IDEBIEGPCFCIEKAKCIEACBALCDCLBNMHAD@P@THNBP@DBDHHD`@FA\\WCCGAAKBCBABMLID@FGDAJL^FJ@TNFBDLBBN@LE@ICC@CDAL@H@LJBFFLDJLLD@HEH@JDDLBDJ@NHVH@DEBM@OL@FCHKHCD@DHJADGD@JBHNVLb@FED@PBDLBBDCFHFBHJBBDCH@LKLCD@DDBRDFDFHBF@VJNBXBBJHHNDDPHLTFPGXIPILCNEF@DDJh@HAJADABADO@AF@LHDLBLDDN@BDHBBNPFL@BB@BAJ@DHFBDCDKFABBRELGF@JCHDDBTBDLDHF@BMDBZDRLLDBFCDC@GDCAKBCD@FH@NJGDB@PLFJ@DBLCF@AJDBFLBFBD@RBBDAFDFCBCPETHHFHPBpB@JODQRMFQJQBKHSCM@ICSACEGFGDKI[BYCCKCBECM@WCKDMFEJEHCHHFFFFHNFBDARQRBH@LEHKEGAGGM@GCC@GEE@ECKGSEEAGKAEE@C@GIO@KESBECEAICGA[HU@IBGAAC@@EFGAIFABA@CHCCSFI@EGGACFG@EAGHAHODCBCD@NBP@HBLGN@LLH@HHTFFABCCCBIAQBICM@IEMAGBUBGAE@GECCIBEAEDMDC@GM[KQAIACKEK@IEK@MGAC@UNU\\BHCBGNBJEDCBECI@KAAECAED[CEEEAEAKACDIAAAC@ETIBMAODCF@JHHBBAAEBIJOFCTAJADEBaGGICIc@K@KDCFCLBNILMBEEM@EJE@AAEOOBGAAE@CFGI@CBEAAAWAAKACABGDCTEOICE@CACKBGCSMKKCU@CGCCCKeEGCADOAE[KQIQGEKGCCCACFCBEMMKMCAACBELC@EEME@OBIAGBABCHKFKLEDYDQTGLCBE@UICCM@OGCCEEEIQCIGEA@Q@EGAAE@EGG@ADA@CECC@_FMCGE@EDKHIBEUIOAICKFCFCHABATED@BDD@FADGLEBG@CBBZLNKDOBIMGEaQCEQDEAIEBIOBMHYEEDIACEGSBCJBKMGEFGGMKCACBMAGAACAQDMECAOUQKEGCCEO@CJCBE@GGIEAIEGAC@@BBLC@UOIME@C@@DJL@BCFEDCBO@ABFPFD@BGFAFBFEHKDNTBHDDHTAFCNEBGFGB@DCBJPNF@FAFED@DAJEFUDQ@IBGD@BBDZDDD@JOPI@QEECOMC@KFA@CA@CUKGACBCFAHABO@GFGDGEKACGCASAMEEDEHEBETGLIBELDJEDSBSOEGM@IEC@GBKHC@IASKG@YLCD@BPP@BWRMBSJAB@BFDCDY@MVG@MIEAIDI@MHG@IEIAIACDABUEGECA@CFCACECI@AA@CFMBEJO@ABCJAHBJBD@JBLAFCBGAEACCGOECESGSAW@EAAAECE@SFWG[G]CA@CE@GEOLEBMDAFKHGDIJKDKFCNCDCFCDYEKJICMBECEDCJFHAFBBCD@B@@GCE@GAEC@CIKGIGE@CAEFGBAHCDKACE@CCAI@MGMD@BD@AHKCEEBAACEAEEO@@ABEACEAI@CCC@E@EAEGC@CCC@AFE@MGEEE@@CFBBCAMCAC@CCGA@CEE@EGE@EDGBBDBFABCEABCACGIA@GFC@EIDCLC@CCGBAJEBGLED@BCF@DA@AAAEBCCDCPEEG@CD@D@JEBA@ELGBE@CCEEKDCD@NCGCGIWGAEKEAECSMQCI@GDIBMNGDC@ET@BANCLDHDH@JDN@RATEBEFABEJMNE@IFAF@LI@KFEBALADA@EDCNKNC@AAC@CDEDAFBDABGD@FCDBD@CIDE@EBCBKDECK@EBEPKBC@ANE@CLIDEAKCE@IBGCE@ETI@CFGBGNIJKDCPCFC@IJQ@GIQLI@QCCICGKOGOO@MEIGIDEISCGDIKOABG@KCE@SFK@MDOLI@CDEBMCWDOCMBCAM@GWEEI@KDEDCTEDMFE@CGC@GG@CA@EEBC@CCAACCA@CGCACDEGGCIKM@E@EAEEGBEA@@C@ECAEKBCACDCBICCGCAC@EEGCCE@CEGCACSBEEQK[AGBOXKDW@GEMK@@OHIDOBIDCBADDNM@CDEFEDG@ECKOY@ODIHEF@HABGFIFK@GEE@OFECGDKJM@A@ABACA@ACKFAFIEEKGACCCAO@ACBGEIECKBCC@SAAMHABICIHAFGBEFBHGLGAkDAB@FFJFR@DCFQB]NIACJIDQAE@EEEACAEBGCOPAHKFBFFF@F@HCD@HEFAFNFD@HCF@JEFADBBBBFBDADCDDD@JHFLBNFGJEDBFJFCFEDADADDJQLCHILDJIXEFA@AFC@@BC@ABABAHCFIBOCCEG@EH@PGJMFCAED@FJHDHAFBBGNTHFPKDKFE@KCE@@NCHILIDAFGDAJGDBFFDBDAFOBUCEA@NGLJNNCFBNGD@DJLFGL@DLFDH@FPDHJ@FG@EHQD@HKJE@IEGCCIG@AAMCICIACCACQBWME@@EBIDCICKAABCFC\\ADCBM@CDBFCDCDI@CHBJEBGJQJABCDBHCBOEGGAK@KEE@FADMJELKFKE@FADFHFTBPABCHBHHDD@DDF@DDHCDCNBHPAFDFAHEHCNED@DCDGDM\\OPKFG@CCGCIICAM@MHCBCAEDWIBGACCEAMKDACGEGBAEAAAMEA@GAA@GCI@EG@EDEAIDKCCOEAG@EF@DABAF@DBXCECHOFED@JEJCRBFFDPBBHJDDJANKLAHBHFF@FAFKNM@IHEFNFNLTJFBFDLBFA@DMHF@F@BBD@@BFABDDAAABEDBHADDDAF@@CBEDEFHVVDRDFHDXVDDANFLFHRPPHFJRBJFE@UTAFCD@JGFCDE@EIEBMHEJED@JEFAHEF@HCDCJMPOFUCK@@DDDBJDHEJGNGL@ZIDMDKAE@WPCJADBHENBFHHBFAJCHQTGPKDMLCFE`BJFN@BADKDGF]HIJANITA\\EL@DDHCHBH@H_ZSZCHFHCJ@FCDEJIFOZS^CLOJGJ"]],"encodeOffsets":[[[105527,24614]],[[103708,24876]]]},"properties":{"cp":[102.543907,24.350461],"name":"玉溪市","childNum":2}},{"id":"530500","type":"Feature","geometry":{"type":"Polygon","coordinates":["@@BALEBCCUAAGDAABIHMACE@ACBK@KFGFAXHLAfB@DFFJBHCDONYRKFG@QDGGEOM@GFKGINQJGRaDARFP@VJP@DFH@HJJDFJJFLBRHBFCBGPADCF@JDBPDVBHCBILADA@GDDBDBBFHBBD@HHF@FAPJDDBLDHRHX@HDLAJDLGTGJAFINIHKFAHAPDBAFIPCJ@NDH@@EIM@EDIACR]JEJYDCHAFIAIQQCMD_DK@GEIM@EDGAGDMDQNI@CDECEDEFGAG@C@AIFCDIDEBMBQ@KBCDBDADIAGCAE@KFC@AAAEFG@IFIBAD@TUHGJQHUFGLKFQJMLMNK^@D@JELKFQAIHKHUHGHQHIDAFGJEJQTKLMPGFITQLMFCFIFCJWLEFGJCDCJEDEPGFKHCNSH@BH`BFFLBLFHBDCDGHMBAVE\\OXAlITKNCFGh_HKTFDEHEH@HBFABEPOJGJBDAT@FFJALDHFFBFBBBDB@DDHIJ@DBBH@@JBDH@DDDADFJ@FCF@JCDBBDF@BAACDCDB@DDDHBl@LBNDTAF\\@DEJ@DFFDJHJ@JFFJNPNFJHFDFGTATZRDBBADDRLD@PAL@LFJBJFPDPLB@DQ@CGK@CRGFEFI@WDIJEHCPCBADMLIBE@SBANGBC@MFIAOBAHHTJFBP@PEFBLDTKNEBC@ASQ@GHKNGDCBOHK@GACGCWGSOGCCAS@uMISMOKCKAQDO@OMQSKEGAIDI@IKEQII]SQKMCOIIKEK@I`oLIEGYOUiICeAGQCUlaJEDAQG]GKCI]IGSKYIKGAOWLKNgDIAUIQCM@MAIWCW@MAeU[]OAMDGAFkFOCSO@Q@UAKEO[IaCACEEAIBIDCBIIGMECQEACBCLKHERFF@D@FEFGBMAGMGCC@CFCPADAJU@IKO@CBGDANBHAEQAMMAMG@A@GJIDAFE@E@WASIEeLODMAOGIWOMQKEMCMKMOcIa@KAUMGGIMCEAGI_Y[BaMWAMEM_QUEOAQDM@MUGESIGKCSFGDKEMICIOE{LaLOCQFHLIBJVXBPQ\\INKJARBXIdQ\\E\\EHCJ@TSPINANGHSLOEW@aEIQMOIQAMOE_kKIIMDyCIII[EMI@OMIGAWUAOIMSOscSQSCCAKYGEEAWDK@sSYFQBCCDKAICEIEeGGC_CWISOMAOGM@]IQ@ICCAMUEGaUGC_cMIGASEE@gN[CQ@KA_AGAKEOAI@MHOEC@YDM@GCEGEFEBK@GLE@CDI@ABDB@NL^BPGDADDV@HBFNHLDLHZLLL@FGJAJIfEBKLKNCF@JFF@DAPCFAPBHRbBTPFFLAFDJGFEBCHHPDPBBJDAHBF@DG@KJADBHGHFJAJIHKF@BBHAFGHMFGF@BBFFDFBBDCDAHBHQXAFDFHAFBFHJFDFDNHNNHNFHJBDADE@EDEDEACBADARIJIFCD@FBB@DI@BHADEBOFCF@JBBJHTFBBGLETCDOHMECCEBEAEDGAKNM@KACBCJA@MDIFIAGBcOIBGAGDMAIGEEECEBGGOCKGCEEBCAQASKMBSJC@CCE@QGEIE@CNBBDBABGJIG@BFR@HDBJ@@DIHBFEBDFEBBJUPIDCDFB@DGHEJBFDBEBGFI@AJKBDHADCB@JK@ULIIIBDDBJCF@FNHBLJBHABB@DLPN@PHCB@TGTEDGBCF@FNXHN@HGN@NADABQ@GFGZILAD@FBBTPJ@JDLAJDT@LDLHFLHJRLJLHDP@NGX@LCRDDC@EJCH@BDAJ@HHN@BEJBBFDBDIHKPIPCNEJAFBNAL@TCPELWFYBUCCCDIACCAI@IFMCEEC@CBC@[WMEIDCHBDHJBHCFKLEBWAOFIEGBCEOEEB@BBL@DKBAAMQODO@C@EGA@EFDF@BADWNA@BGAAAAGBIFEHCLFHEB@FDF@BGFADGFABEA@BDDFCHBHKJCD@@BANAFKHGCCCKBDPFD@DKFGAECMM_UY@KAECEGQIGMC@GFEBGFEJE\\BDLA@FOPQJCDBRHdALCD@FDN^pFHFDFLDPBPFTRVLDBB@HELS`OFGCSKCACBGLi^GLELEFW@CFIBBHAJIFGNDFEFBHEFBBFDBHJNJB@HD@BJAD@BPVCLEDALBLBB@DHPBNMHYLKHCHEBEAGLBHGNYLI@SESHEHCH@XKJCFDRCBI@EBEHEPBHHFDJHLDXAnDHF@NErOLDHNJdBR@XG@ADHFJVB\\AJET]pGNGPFHJFbHPHFH@LDJPJLLHHH^MdG`M\\CJJFLAJCRONARBPALCPAL@TAVIbWPQFIPQXmFEN@JRN\\JHnNL@PHHFNTHDN@DAHBNC@B@JJVFTANAvDVLP^N\\H\\BP^DJC\\KXDNHLLJHNHFDJGbDNNRHHPXHBFHRLFFLTNRRH`BPANELMRM\\UTK^IZKPAHBDJXRLFTEHDFdHJHHRFFDHJDHJ@JCDIDMPMBEI_IE@EMECE@CHENcJGJGNANEO_@CDGCO@AZKFEAEDIBM@CMMAA@GJEHCBCDGROBECQQ[@EDOCQBCPO@KK[O{@EFKFIHCH@B@@UFCTCJAJANDTNLBbC\\GT@H@HCJBLC@BCH@FBPBBL@LT@JGL@FLLHJBLAFOLKDGLCRJFH@JEJBBDDETIN@HAHBFDB@BBJDBFLABDT@HABBJBFBTGP@DBNGRAH@FARADB@FDBBCBCAM@EIICOCA"],"encodeOffsets":[[101378,26221]]},"properties":{"cp":[99.167133,25.111802],"name":"保山市","childNum":1}},{"id":"530600","type":"Feature","geometry":{"type":"MultiPolygon","coordinates":[["@@E@C@KDWFIAUKECCK@G@KDGVKLAFCACKKAGBKR]@CAEOKEG@EDQNYBQEEKCGKAKFOHGFARBDCACIMAIBEHKHWDSDABCJ@AIFGVGFAIMOO@AHAFITCP@JHHBFDFJFLNNJHH@HADBDDFFJCP@JEPEDABMFM@UNKAECKBCPIJOAIFCRA^JJAVCDAAEEGCGDELGRODECIQCCKDKCGGIEEMCK@UACAAG]AAEBILU@CEIDGHBD@JGTAJAL@PFLFHCDE@C@AWEACFI@EEO@OBCHCFK@CAEAMAEEAYBCABOGCAEMEOBYMCGBOCCAEDIGKECK@CAOQMAWDMBIFIBMG_@WCIEEAAE@CTMRILADADG\\EJCF@DCFBFCTODKDCLIFG@EIBAA@ADEXU@CEKDAJCLUHCNBNCPSJGLAFCDGFCVC^_H@BCCCBCVGPAD@BELAJWDEFGFALBFDJNFDJ@PELKDKF@DDBGLI@ACC@EDIAEDCPA@IDGHCJBFBJJLDFBXNDBNBHAPBJMBAB@LHXNzjLDLAHBPDRJ^LVDNFP@B@@GCC@GAADGPCPAHD@FFDbHDFHHD@BCB@PDL@BADATAFBFHFBJGN@JBNBLDPBZLDBBF@PAJDFPJTDXBFDABIPE@Q@AVDHLFL@FDFNNRBBFAJETA@BEH@DDNXPFVRDFDDHEP@JHb@PBFHDlBRFFFJDj^DFDNBBFBX@FAAEDEHCL@FCBEDATFTGTALGDEHEZATGL@F@HDXFD@BEDEF@FBDILIDEACEMBG@AICEIKKEG@EJSNQJKDAtGHAH@HDDHNLBBJAJLJBBAAGDCDAPAZGES@IBGFENKFOAWFQ@MIKGCGEEQGEE@KFC@C@GCYYEG@GLM@KFGCOLGBIAMJMAEQWBCFC@GB@JFTDFGFEJEHAPBH@FC\\HFBPADEAGCCIACD]EGC@EBGCGIAEDICDSFKHEPGFE@CGEACDIFI@CGICGHUAgJCFENBFEEEAEEG@UDKLQB]CIEE@EAIQMBAJEDEDS@EACGESIIKYSEAWGGGEKINC@CE@EBCPG@CCCQKACFC@GSGACBCDEH@RJDADEH@DACCCCHOFQ@EAGGKKECSCCK@IGAE@K@GBEFADGIQBGACKIEI@EJEDEEKEKAGMKCKECAIIGEKIEGECCAEAKCEGEGACBAFFH@LDVEFG@KDIXCBE@IIG@E@EHKDKJKBI@ADE@GCK@SIE@EBKJIDOBQCCAIIGEWCAEACFGCEC@GHO@WSOSUICEBEIBIGKAECECKCACO@EAEAGIUIIICGEEGAMCSIEEKaCCE@IBEMGAQAEEIGCFGBGHOBC@ABAHDPEL@FHNFDBFKHKLSBEFIDABAFMBECC@ADGDCMGECCAEIGCIEAASCAI@ECGBCAE@GPBJMLGLEFKAGCGKGCGBUNKCE@ICGAGBIEECCBI@AECCBABCIE@GG@[EC@CHCBU@ECI@OC[QKCCBIHEBKC@@AHE@CH@DADKBKJMFU@MCM@AEEACD@DBD@JGLIDSTBP@FGHGPGH@HGJBHNJDDIBCCG@CCIB@DQF@FNL@BADOBEEQFG@E@EAIFAFGBI@EFCDKBKAEFAFEDYBABAJADGDAH@DFJADICE@EDEDI@YJE@KCOJK@G@MGAAFCGOKGIEAABCDENGAE@MC@@FGFCA@ADA@AOWBC@CGCCE[@CAAECCCKBIIMESKEKGE@@LA@CADKAKEAGBC@CCCKCCC@GCAA@EEA@G@AMGDK@ACEBAFA@CCCJGDGHGAAECAEC@CCFG@CIEGNEBQGAEEACFEHUFCCCCLIDGBABGAGYCIFEHC@GFC@CGBKAAKMKEEGOJGJMNCBIFGJCHAHGFADKJ@HBF@FDD@FAHEDWHGNCBYEKGSACDENOFGFIDIRMDIFMDGFKFGFCFEBGPFLCHDHAFBJ@D@DAFEB@BANDFCLEBGACBECGCACEAEGGAG@ICINeDAFBHEBI@E@MJGLE@I_A[IIAGCCEGAEAQK@EG@SCqDKICG@EAKI@IAAQDECAQDE@IEC@MK@AC@WAGBKC@EFEDUDIGAEBI@GICEGWEGBEDC@I@EBGACCB]AEC@GDEHC@@CDOACKICI@CK@CAHE@GI@GCCECACG]AACCQACKGAECOEACAGEAIMWGEC@IBC@AEJ_@CCGCAKACAGMKHO@GBC@OGMIGBEDI@ICACGBMCCEGAACEGAOCE@CAAPAJIRAPFJANkAIGBIAE@QHUFSNC@C@CCGWEEIA@CHIDG@GLOLIHBDABEAGFODEAAI@KKGAAEDAACBK@ECEECUAEAaDQFABALIFUFIEOAQAMMMAKDSJCDAHEBC@IAKBCAKQICOIC@ACGAM@SPEHCBGBGBCFKIAEBCNCLGFENS@IKK@CHMAMCMCGAGCICEKGCEEW@ICCCEUBEDGBCE@CDETEDC@SAABGEACGAMGMEEQO@CHMGWCSOMAOGUKKAIDIJIDGJGLCFEDG@KKMAIBEFCRBDA@CCAEC@CHGJCFCBGCEGCG@IFQDKBIDANFTADEBK@MEKGGMSMEAI@IDWNEBGFCLIHAAAMCCEAUF[@GAGKIBUFG@IG@IGYDEJG@CKGMQAE@EAACCG@CC@CNOBMIICCAEG@EE@AHMBCEI]SsMADC@CJCDMDOHC@QHAFI@MHOBKEGABKEMWMOEGHMAEACC@CHC@CYKAADCD@DCAWFOCEGGAE@OAUBGDGFAJ@RDDABCSASEGDGLGBDHCNCFIBQCCBCFENANAFCJORAF@FRJDFAVCJDL@FEN@FCH@BHJ@FAHBN@FIHOJEFKDAD@RDJAJBBFDAPCJEDGDELAHHBDD@JCFIBADCREHALIP@BJFFJADMJGLB^@DGLIHIRBFDF@HCHKHEBEAQHQ^QRCHIHITKRCNULEJ@JBFELBPCFGLAT@JDDDJ@HDNBHCXBTENIJ]XAF@DDFJNDFJfJNLJFH@bTjBHBNFX@LCN@FCHETCHHXGNERFPAtET[RGXAZDJBLEV@HDFNJHJJRFRJXHVT^BHBHBFHJNRNdFJFDF@H@HMBOFONQDGJGHGJCJBPHPDRHF@RH`Z\\^NBPCDAPUB@RDVCXHPLLL^NFFDF@PAdJRDJHFJVNNBJFDLFFD@JBJJVFHNJTFHHDLFFDH@HDJBPHH\\J\\CN@JAF@DEZET@LHBFC\\BHDF@FDDBFAHMRGDMLEN@JDFHFD@FCH@DBBFDDRNHJNLZRLHBFDDF@RHJLHTJLHLDFTHD@H@PEFBDHBFFHDHFD\\`NHVBDFDHLBHFJNBNHPFFRHNFTP@HRVV|@HIJALBHCJEZDFBJ@^BD@TNVVPJTRPHHHDZBHDDDFL@XADEBE@EAQMGIGAIAIBO@I@SPCLIJIj@FFT@LCFILGDG@UCECCIMGC@EBEFIB]`AFAFBLALDLBNFHTHNNBBDLFJ@JKFEHAB@NHJDBVCJBTVHFLFRDHDFNHFJHNHXPLLDNBDHFHDFFDLT^BD@RFJJHPTJDD@HBBXTLBLA~i^KFCFI@ECWBEDGLMJAJALDHFJVH`LLPFD@ZET@H@JHRbdRVFNNPXBBNARDTN`PHJDHBHCPIT]bELBNL^@PCNMbSVWfAHDfCHENEFYpc\\GLKNAFDDNBFDNHDDD`IH@DDJbPh^BF@JIZBdRT@JET@FHTNPHBRABALOHO@EG[DIDEPILCP@HBFDJNDDJ@nQFGBYBCBAFAJAL@JHJFVBPFR@`NJBzJFB^DJADAJINEDCDMBCLENANFNLBD@LDLJRHDHBPBP@VDTARHFAFENCTGJBZHL@^CNFDDFN@FCPBDHFF@HE\\kLKJAZFF@HAFCFC@CAQBCFCFANBLFHFT\\TL\\HbHZKJAPARCPMRK@CEACE@MGUBIAACAOB_DE@YGMQAMCEAGGGAEAOCCMAMBMHC@G@ACEKAKCIMGKDWBQKAC"],["@@C@CHCB@BD@FENDR@@AGAIAKC"]],"encodeOffsets":[[[106793,29218]],[[105876,27375]]]},"properties":{"cp":[103.717216,27.336999],"name":"昭通市","childNum":2}},{"id":"530700","type":"Feature","geometry":{"type":"Polygon","coordinates":["@@EaAGDCBODGDEHAB@FC@CDABAD@BEJA@CB@DEFABGHEVCJEDBBC@CJUPIJMDO@SBG@MDWDUBEHEFGHAT@`DVALCRKHI@AAAAAC@@ACAGGIECE@EBGHCJCLBHEBCCCSGCOIEKUHCRBJHDLHBHABGEgBGLCH@HCHMV]FIFI@IAEJCNYJMJEFMBMAWEK@EMQAAFKBMGeD@FFD@HFBFDDDJDBLBHARA@CDCFGJEHOJMDIKM@EBGT[@KBEHELCDAHUJMPIJQ@SHKLENBHAFC@CCE@CBCDCBCOQEKCIbWHMBO@IGQ@GbqBMICAADQDIHITGBKAGBCFCPCLCJAHBHHHBD@BDD@FBHHPAJBDBDBD@FELCFBRCFCD@BCDA\\@LDAAFE@GACAGBECC@CFG@ECC@GIWIGBAAEDA@GKSBC@CBAAEIECOGO@CNKJC@SISKECE@GDI@CCEDKGSII@CAQBG`QREXC\\MTKLEJ@LDFETKFGEaBIDEHGD@d@XDDG@CKQCIEWNQBCBMHGZCNGFAH@JDJBHHH@DGJGJMDATBJEPDF@JCTCBCBILSVMHKFKLGFG@CCGQWAKQUMGACRIAQYUOGCEBADCF@FBDAJMHEBIBCD@NHDABEAOFIASCEBAFCF@^FLCFBDF@H@FDDJHLDD@LKNERCBBBbIRCPIJCJDJFFTJJ@NGH@HCPKTIF@JDJADABG@KEKE@MFCAKS@GPM@CSKcMAAEQAAE@EEIAEECOBINIH@JBFMNGDECCGQEC@OACSS@KJMAIAEBEEUUKI@KFG@C@GCGAA@G@mHCCCK@IJi@ECEGE@EB@FEDCLBCOCCIABCFEVRHDBCBCGQD@DBBA@CBEFCF@VNFAJQCEEIAEBKLGXWFEBADKAIOOCK@IFINKFAL@D@DCDE@QBKAEOQEAUEKGOAEEAGASEKIEKAGBIFIDQ@ODUASCMEaUQGG@MDMAKCMG[C[IGEGCYDIBIBKC]IIA]HGHCBSBE@OKMQOIGAe@[EY@YQGG_QMEM@MAIIMCIIOUIGEKKMKIQGGA[MIEOGMICEQKIIGCMMOIKMQOGQISEO[_GMICEAWDQAM@OVKJOFUDIFCH@HJL@BCDGBGHUAMCUOMEaFGAACBMCMCCEAOCCA@CCCOI]ISASCBEEIMEKCGCAABIK@KGGBEABQAGMKSGKKAC@EJSDGAGGIDQDMBG@MDEFQFIDUJMDQIAODM@GDAGIKEDE@KLGDkICCEAKGS@C@AEQCEJBFCLCDDRCFICE@IFBDAB@DKBWJIDCAOWIEO@IDGCMJATILCHAJ@JDL@LBNEDEFEL@RJRIX@DFDNAFDDF@DMVGPMHIBWKKCSBOHKLGDADDTWfBNDHLJp^@DCFI@CDILBFHD@LCFSNKT@TIRET@JBNCHGJEFKAC@AF@DJRLLTFDADEFAFFHADD@HED@D@FPRDNLHHHFF@BEDMII@CBCFBJRNHHBJ@VLVL@PCJATBXCDDDVENQJOBAB@HCFEDE@IAKKIEGAEDKZHRCHEFGBEFCJ@FBF@JAHGFFJJHNBRED@DDTALB@NADOHILSFEDBHPVDPAJOFE@eEQBEDCD@FBFADEDCL@NsJI@UEC@CHALHHDJJJBFADEDG@@FHLITC@CAEEAGCMCEG@MFAJDNBJ@DHHBFABEAK@OHA@OEGBOAWP@DBbADC@EEaAKKG@MBGAIEI@CD@JELAFHPG`DFLJANCFSIGCKCG@QLIIOECCAKGECEGUS[Q]IKISEEMCCEMCGGS@EFEAGEGAADDNADIDW@A@AFIH@LAFGLGFQ@GBKHI@IYAYFQ@M@OCCCAQ@IKI@UGG@oZeJQJIHOBMBAF@FINcXADOHUHM@CA@IF]@ECCIAY@WFc@]CIBGHGJEFQBABCFEF[HWAOGSCQEYOEBC@GKACYAEBSJCNQR@VCN[X[LKDYBCAUZKLqPCJAJB\\S`CVMlO\\ER@LHJBHEFNJAFAFDHCDE@UEK@OFCDBFDDHCNCDAFBDDAFBJJJBHADQAIJEP@LGNBFFFAD@JDHBHEF[N_CGDU^ANMNIDCFCTERBNEVBFEHGBELIFMtKBUJ[\\CT@RKBEPAJ@NJbAPOHAF@FBBJBNALE@B@NADKFAFBlGJCBU@CDAFDRIJKF@D@HJRCDKFC@IDE@AD@DKFAD@JCBABBBJBHDDDFFNJZDDB@DKXMfO`APBPBFDHL@LDDJDLJNBJDFBJLNRP@DED@FCDIDEFAHBJMBGF@LCJ@DHXAPCHINAFIHAD@FHVJJFBBBGNDLINAF@FBHFF\\BZPREPBVFJDPBLDX`BBCP@DLVAFCJBHDB`HDBLJbNBDANF@LGDO@KEQBCPOHADBFE@ECWGMCO@EBGJI@MBMBCLCPKDE@GFGFANHNCDCDGAEACGEAA@KGKAELIPKHIFMAOBGLGdQFCLWX[AE]QACBGEW@EDIFEJENCHEBCCWBELCL@FADGACBCXMPGDEBOBEDCHAXABCBKHGNGFER_RKbCFAFGBODC\\GHCBCBOBQHKPIZGBAFIDGHGJMTI@MDKRkHGFCF@NBF@FC`UDE@EAWBEDEVQRIFGFMJMCK@@HGJEXUBM@MHEHENODG@GMAICAACCHMDGBKCKFG@MAGIMCI@ATQFIBOGKAEBGHIJAHBNPNDL@DJDDXFZVRDHDFHAPHHBD@FLRDBDBLADB@BBH@HEdFT@NDJFRPXFLDN@JAFMJCH@FFLPP@FEPARCJIDEHA`EPEFCFAJFvF^DLBFFDRHFDhJF@JFHPJHHJBJLRPNBDHNPXHFBJXTHDHBFDN^HBBHTRHTNJPBJDP@PFDB@HFH@ZABID@DDRCH@RAJGPKLINKNKPLRDJCFGHEbCHKRENU\\CHGHAPBDJDDHFRDNFLPRPHJJLPBLDFbPNRBDER@PAJAJ@JRDRBNFBFEPITBLDFDBL@FBBRDJN@FD@HBJBDPLDDCJC\\ABUHCFH\\VNBLBL@NDLLDDANWHEXADBD@@DLDNRBT@DJHAHDFPFF@JERCBNDJBHCLFFD@FFPLDLVVDNHJDJCDAJDNFNHBDDD@FHD@FDDP@FEDDDVDPCPE`CHCJEDEJGLGFJFDHBBGBKDGDWPIH@NHNAP]FALJFNHFZNDHHFRFLP\\PDFBF@JCJBJDBNTFNHNNLBNDDVALGH@JNDBFBTBFBDDBBBA@CAOTGDEBMDIPKDCAMGMACBEJERGLG@GCCEKKGCE@G"],"encodeOffsets":[[103124,28504]]},"properties":{"cp":[100.233026,26.872108],"name":"丽江市","childNum":1}},{"id":"530800","type":"Feature","geometry":{"type":"Polygon","coordinates":["@@G@WI]mOIKFCDCBAFEDBBCDAFADBFAD@DFJ@FG@CDIBIDE@CDEAADGB@BC@MBMEODC@IJUL_LKBSEKKUKWGMIGEYGK@KDUJiHyCEE@GHMF[@YIKIMKAaBaJONMTeZMR@bBZGJGDKHEJAJMBMHK\\ILOJS@KGQScCQKOMSEQ@QBSBKCCGBIFKGSASCOU]OMCKDI\\_RYCMMGK@OBAKBmAEQ@GBIHmHCAEEMAAGECE@KLEBcMOAEBADAHJ`LRDXCDQEABDBBBCDG@ADEDGAGDG@CDAFWPOXFNAFALCHCL@JUVAHC@ABFJCRI^KPIV@JCFDLAFEF@FAHGJBLCDGEE@ABAHKR@HCDCJBFDDBJIJ@FDD@BGHADGIKFEAEBKCACCBCKCEAB@DABIB@AAEC@ED@DEBEEG@CCMEACCAADKIK@AEM@CCIDMACE[MOKcSO@mNK@cFQY@MDKHKLKHKDkE]A_EOBgHSHIJvAFCBCA@DACGDEGE@AABEBACGKAEE@AA@CBEAGFBDEDC@AAA@CB@HA@AIGKBIDCBEHG@AECMCGBWBMAI@]QQOSKEGQEQ@G@YVMDCNBFCVILCFORCLGFK@ECG@GDI@EHK@CDA@EBBCC@@CA@AF@ACA@DCA@DGBCBAABAB@@AA@BCC@@CB@@AB@@C@ABCC@DCKAAEGDCAEDE@AAIA@AGBBAAACFCECAADC@AA@BGCA@AAGB@AFAQ@CGA@@CC@CCCBC@ACBIKGEOGCAA@IAICCIMECUBIIICK@YJIBWGQ@CMAIDSIEKACAI@OEEBCAI@GACGKY@ILQBGCGGIIGMFCAACG@MDGF@DEB@DB@ABBBEFBDQ@EBICKBEDUCSDEDUGQAOAA@I@U@KCEGCACBEDKCGKGAECAEIA@EBCAGAESAKVOFI@GCCIEGIQCMCEECGAIGMAGKAEBEHKKIECC@CAXCLAFABE@IIeFECG@EFMKCACDOAOCGEEAE@EDE@MGECGDMAKGMKEMEGKGGIEKDULGFMBMJOBUFcR@DBDGBQVEBYAKFMBKDUGKBIDI@MIAWR[AGCEGAI@G@K@EEEOEGICeACACEGAIDI@MFSBQRMBEEG@AE@QAEG@GEAEBICGO@CCRWAAGESi}WQgUcDGKI{KUIECEAKAEUHSCWDQF[BoN]BSAKGAIDMPYAIGGaISBQDGLKTSJcHcLaTSDgEKCMGAQGQGMOBSFGJBLHbCJEFM@OAINmhKDCACAQAGC@CCC@AEBQ@EHCJC@A@@DC@CHIHG@ACBEIEE@ECEG@CCGABYfO@OEMEKIQGSBgdSX]FOIKMSKYG]AKCKESGQA_BUHGIKGcFS@gHI@CCADCBBBCBCHCAAFOGC@AAEAMIOBOVSHI@ICABA@OBCCC@EECBEDKLIHEABDBBCBCJIBCFGDADQFBDE@@BCB@BKACDCDCHMLABDBBB@FDBJCPDHCBCH@LBNDLH@DABGAEEC@A@CLICMHCD@@J@BBAFGJHDJNLHBRDADED@ANADHFDFHA@BBFADHPLBJ@HBFHBDFBFHFLI\\BPHR@NEJBHFB@HFHDFJFFJDDFXFFFFFFHHVFBZCHMLKLUNGL@FDHLDHDPBH@FBLFHFPLHBJJNTBFAFHLPFH@TLJNLJLRXNBHFLTJFBFH@NCJCBUJCHKLAFBJ@NBDLLHRLPDBFLHHBFENBJYb@DFF@DCDGD@JCFBPE@AT@FEHBDADAH@FDBADBFKH@DG@@HCAAB@JCL@HEN@DEF@DCRGFIDGLAHIFGHCNFDH@FH@DBDABDF@BJCDDDADDDADBDBCDFB@DFCJDDCFBFB@AFHD@FFTCF@F@F@DT@FDHEL@FFPDVAHEDRH@FDHDFHDNCJBHEAFJPD@H@JHDHHDXBFBPAAHCDCFIF@BA@@DAFBD@FAD@LMR@HAF@JGLBHGPDDBF@FCDBJHJHDTCXMNKLELGhUtKPD^PNTDRG\\[hQDEBARKRQjANZ@JC^QJIDG\\CXIRLPNFNBVFHDFHCPPPFFLFLHJFHFRLZLHAJGXEHIBG@IJABJDBTCHED@BBADA@BCA@GH@DCFBFADGFEHEBBJABID@LIFZVBDDFLJvnLdNAWxI]pcPDVRrJhBM|mAvQ^Bp\\`^PlB@@\\ALG`OjFxB@xMrLdljJBRXXvBrHPJPHbDXHNJfNT@JCL@PBFLDPH\\HF@HEDKXEJ@PNJTHTJFZHP@PAFCTULSDAL@FAHEPAbDLAFBB@JGD@DDBLHHJBFALBPTDHDBJBLJJDHJNDPDNHBFMLaNQF_RIJCJDNFP@NCLMVKHeLGFCJBJDFTN@\\ARE\\G\\HJFJDBBBDTKBOJ@F@FLNFLDBFCDIP@DBDFALDHDDDBD@DCFJDBF@LGD@BBJbJPADCD@DBRFB@DCPCTGBAJSDGPCN@DDF@^[nJZATMLMR@PCRVZPHPFN@PIdGXHXDPRLRN^LpHN@\\DPDXCLAXENBFBVGdUXL^DXGX@RCJFVCTKZLE`FPErFRFNDNLNhXNL@FAHADOLEJCNAR@DADGFOBMLSDGBALDNCLEL@DFL@JCH@HABIAGF@DDJ@DADMNALABQJAACGEBCHAPDFKLKDAD@FHF@BQBEDADAJEHMJMDEH@H@FJHCVGJEFEAGCGDCJDVBJFJAHNDDBFCDBFFJRJLNLHDNCJEDA@GBALJHJVHL@ZID@BDHBN@@CAK@GDEFCNCNOJ@\\F`ODAJLPLLF`\\LFNDFDPRBHHHBJB^BHAPFVHPGVCD@BDFDCHDJ@\\CNERCDAFKBCD@FFJAJSFID@JDH@RGJKNAT@ACBGDCF@JB`KHKAUDQLGHITELOLGHA@DBDHJPDJCHGRBRFBAPCT@FENCPHNPNHFLNHD@RQIGAEFKFABCHDJ@PCLDJFD@HGLS@EAAICCEASBEDCBCEG@MAGFGbUNKJOHKVqXiXQNYFQZQFM@KEIBGJODO@]DIJKDMHCRCDIB@NABAFIAMDGHG@CAGBENGLKLEjaNO^mTKRSHOF[JKN@nOTKPMJERQRSTOTEZAHIPIDKT]PYJEFIDC@EDIEGBETWb]@GAGDGCG@CFKB[JSBMJI^GHELCBC@AEMAIF_DENKLCHORSDGBIAEGGAEFMAGBCDIXOF@LBNCJC@YHKHMFICGAICC@CL@VDPENODIDC@GFEBGFE@IFCFINGFAFJF@DCHE@IDCBEVSF@GESAEIOGQOEGEKBMCCWUGCCECQUUEGCFAF@DE@CBCCGBCAAFBBCBACEB@AC@AAE@E@NG@CEBKAECEASIMKMEFEJGN@LMBE@EEEAGBGLKBMCIICAGOAECAEDQFI@IFCPEDGDFAW@CFKDGNBBDBNLDJCFBFCH@@FDJ@HBB@HFBBNBBBFHAHFBDLCBNDFBDAHXJFCDBDANGN@DBJJHDDDH@LEPON[HCDC@CFCDMFGBGCEBEGOMACDGDCCE@CCC@GCAGDGBAAOESEGBC@ELFLEFKNIBC@EFF@LBLHHPFDAAGDCBARIHIFAAIDGJ@DCDCAEDCN@DABCD[DEBALBJDCDAJ@FF@XNRABDDDJBJDNDBBH@DJHDJFF@LI@GRCFGH@@EGIOC@ECGKE@CHKKECIC@MHEAMDIMHK@MFBVDPABEACECAEHCBIHCBEJCJKDG@MF@LDF@LELCEOSGHMAABECGIG@EFCDBNEHI@OFGH@DFPDJADEBGBABAD@@AD@BEB@FEJWCIJKDGRKCIBCBCFCDEIEAEFCHIMEKAGE@ICCDCBCACAEAACAEBIFE@GDC@KE@EFE@GDC@G@EEEAELEBGPOHDFADBFBFFF@RBJCDIJB^MRCDC@CEQEI@GDAJ@`AHBHKAGBADCHAJKDAHDBALGJ@@B@MCCE@DKDE@CCE@CFCHADGN@DE@CEEACMIASGG@GEECAADGIC@GDA@ABE@CBA@ADA@ACECCI_A@GC@AGECHMDEBCAC@CDCDABCF@BC@EHABCAEAAACEEBOEIAKII@GCEBGFA@CDA@GD@DBFAPKL@PEHBLAD@JEBCHCH@F@PFLHJBBDFALDHEBEACBEHBPGFDDCBBBJDFJAFA@FBBCDBHGBCD@DHFBJJCHFLDLI@CDD@BFDLTFED@FBDA@CIM@GCCGA@CJEBC@CRBFAJAACMMDKHAHCNBTCJEDERKEKBGDEFADGBCJBFCH@R@NGCE@GCGKIEGECIAKKDKLUNGE]CEOKAA@EJI@EACCAOBC@CEA@CC@CCIECEGGEGKCCA@CFABOAGC[AQ@QHAB@LDHEBABBFCDBHA@ABA@BDA@BBAB@DEDAGKEE@CCOEYAO@MACBAGABABBBABCDAFCLQEG@IAIAICCCDA@EEEGQAMFMGMICCAEAKDEE@CLI@CHKAEDI@GFE@CGIMKAEHQ@GAGEEC@SHIEIMMKCGIKCCOCII@ATUFCBGHEL_NILOFCNAHCTYPCHEHID@@BD@JCDEJBFCFBNJNZDDLHLBTCPGFEHCDEHEBEPINCRFPAJCDIJK^OTaFELSJEFEFCXUJEBKAE@IAEBSDMBIBIHMFCBGLODKJGTEVCNCDClWTCJCFAFCTBLDFADCN@HEJCHGHCD@BFVNNBPEDCNMJGH@FCBADFF@JGFALFFFF@BDF@LYAEHEDG@MHGBKJGFAHCDEPQHAJB@IBGkccwKUDMHGOCigBEHOJSHcAIMBsXFm@"],"encodeOffsets":[[104636,22969]]},"properties":{"cp":[100.972344,22.777321],"name":"普洱市","childNum":1}},{"id":"530900","type":"Feature","geometry":{"type":"Polygon","coordinates":["@@BCRSJEJ@DCFeFKAcBQJWBEFCZIJ@\\HJ^BNBDHFFHRAF@HAD@DDHJFLJDRANKD@F@DBHALBPIFBBBDBHCDABBBDDBH@FDFAT@BADCBONATBDCBELEBCGS@YEQKK@A@MFICGACKECKGIGAAEDKCGEC@CHGACCCBECEBGGIAGEGCK_WBKIKDO@C@I@UCKIQ@GCKQKAECGCWBSCEEASBMOCCKAMOEYN]AYBKHAHCPCL@LDHFFLARHHBL@^DFDBPAFBHH^RJLVNJJ DLFRB\\H^FNFNDdDL@HARQHEHANBLHF@FCBEBELSJKJAPHD@DALWHEVCFQGKC]BGDCFAHDFBFEHIDSACGEBODENCNIFGBIBCFCRA@AGE@EBCLCLKCEBODGFADHBBTKBKNMBC@CCI@CHEFBD@BA@GDC@OEI@CFKDKCMBKHATCNKPAHEBC@CBQFSVSBMMKgWKMCMEMEQFqEOF_KLYDSEUDI@QHWCWK]VWHcAUAEFMBWDKCWCO@[GMKo]QMQKOWCWGcHOJM@OEOGUYDQ@ONQNKBSIY\\m@]CE@CDMHOTCBIHADSDO@CEAAQ@CDCBCIOIaAAC@KHE@CAEICDC@CACCCGBKCECAO@CJEDCAEKKM@E@EPILACSAACAEIGIH[F[BQ@[SMCEAIDIHEfKLGNUDK@MEOCMDIJI`QREbMNKAEMGOCMCGIICKIIACACGOSKAEBIAGGAKCCC@IHA@EAKBaCOBGFEBK@CBKTSVEDOBO@YGIEGSISOMI@WFCLGFE@[GOGKCAE@ODK@IMSIeGMCWGaIOGOAqWuQWIAkiKcNqwA@EwPiH_BK@[A@Ok_]o[]AuRB{nNgAqIUQOCod^wJXMBKcumKICEACYUJE@KJCBAAIFAFGHEBCAEDE@CHGB@ADB@BCAAC@GFSDCAAIIBAPCHGFSDKHEBYKQKGEIEOKGAKIIKDOEGGCUEMAMEGICEJQDWH[aJWDQHQ@M@OEYAODOFIHKDM@]HYLmfILIHUJK@KABMCOIQKGSEmAMCIGS[IGWDGFCLEDGBECKAKBEJIF@JGL@BG@C@ACGAAAA@EGCAiDGCe@iEWJC[ECaLqZcTALF`Th@JEHIGOFSIKDYDMACAI@QHQBCDIDEAK@GCADCBMFGJQBEBCDCCI@EJKDECI@GDCAC@EEAICBK@IC@DABG@AFBDADBB@BBDABHDDFBHFHAFGD@HDBF@@BFBHHD@DDBJHJBHCFDJANDBBFNHDHHDHHAJAFCdEFDBLEDDARJLGDuhW@YOIBIJDHJDNLRXHHL@VKJF@NEXSh@ZHNDJATYPGNBRDRMHUVMTEDSCACIDIAECDECAGAOBGCGGE@AJILIVAZELOV@TBTHNJJv`HdTJFDLBZELQJOBeNELEhETCbOLMDMJELLPHRDPER]bERKVILOJO@SI_CGFAD@DEAGB@DEFOAYHOAGEGCG@EBGNAJGJEAGBSCFPDF^LJHHLJPELOP@FJTBREbQ`APHZHPNPDRAFIDOAGBQHAJPPPTZHPIPKVANLXNTXNVJXLJTD\\@TBNNNTJF`LXNNNFJHXjXFHJFBHHF@FCHKBADBHDD@DGNCROTGFBBHDbVFHNVDBJDR@^JN@PHNBTPXJ`DHDfHJFDFBJCLDDRAZEtTHBVCJ@JFLZDBTDTRtdTPJNBPXVHBNJ@PNJ\\FJJDJCzJNLJ`lPFBNJRNPJRbFX@PFTKHGBMJMTO@SDIFGF[R[JcAWBQLIJMR[AOUWAIJGKREPDbK|KPFDJNJLFHCTELDJHFTVH@NCNBRFPRVN`NFXBbN\\A`ZHJFBNDHJNHBV@LJbPdLNDNFNRLPNJXPHNBPCfKJFBT@X@FEFCBIJ@H@BNHNBBNFRGBMACBAH@DLP@JIVCBOBED@DDDNHBHANEHEFC@E@QEGFKLADBDRFFDHNJJDAJCJAFBDFDBJbP\\LFVBR@P@DTEPElHBNCPB\\^fVNBX@XDBJ@NDNJRBVCJMhKLXBPLHZJTLJHJ^LD^HRHCBIFkbDVHRfBJDVjZPFHKJ_p@JFLJLPJNDRL^TJJFRJLJ@JCHBLFRTPNP@RCLBLDNPJT^H"],"encodeOffsets":[[102394,25634]]},"properties":{"cp":[100.08697,23.886567],"name":"临沧市","childNum":1}},{"id":"532300","type":"Feature","geometry":{"type":"Polygon","coordinates":["@@CGGCG@K@GDYBQLMAIBELCDMAEBCD@JHDAHIBMJKBKHIHAFCAIF@GEK@GDGAOAGIIKSGCKAECGCQKII@EJO@GKICIG@aBEAEIA@ODOHQDQ@MAKHE@ECCQFM@ODCHGBED@DE@CCAEK@EFAAEACC@EBEAFC@AAAGKABADC@ADIAAECEBMCG@IIKGGAECAG@AD@DCDMEAGECCACCKIBECI@EEA@EAEBEKACABEFEAEEGDGBEEWBAR@JC@KHEBEFAG@IFIAACBCHK@CCEECAEH@PDFAA@GIICAIE@@HABEA@OGGEOECCDIDIEYaBAD@FA@IAE@CNIF@J@BDC\\DHD@LGPE@AAEIIAE@AHGPBBC@MFI@KFIAA@CCAGCC@GCC@AACEACC@GBI@CFGDE@ECIBKMKECEXIKEH@AIB@BDBFH@NYBGAICEGCCC@EJMDAFDJMDMCIBEACFC@EFCAA@CBCB@BBBJDE@AA@BC@CFHL@FDHCBC@EHKEGHADCECEBC@CG@AB@DHDA@ECACC@@FDBA@CCA@AFBFFD@@CBAL@LALIJ@LJP@FFAJFDJBN@HA@ACECMIICC@EFOJKFA@CFCDGAEMG@EEEAGCCCEBMDCD@ZFLEFKBEAWDIAEFE@CGGOC@EGKGAI@A@CEBELCFEEIEAAA@ADA@@AKCEBEAECI@SEGAEEEEASKGAGKIEAEICE@MJE@CAGCIMMCAEAICCEBILEDUBICAA@EDI@AU@GCDIJCIEMFCDEHADKMEAKDCBADCBC@GEWIC@IFC@A@EOCACBAB@BHFBBBL@FEBEAIMGAC@IHHVCHGBMCA@@D@DDDNHDD@BCDCJDF`TDZ]@SLC@CACGAQGAEGDO@ACAE@KHKAE@CB@HDFD@ALGF@DGBGLAFGBGBEHE@CEE@AB@FEHG@EAA@ADBFABWBOHEHGFC@I@CBADBFFBBFEDMBADFFCFEDGAC@@FCFAFIHEBECIAIGCCEAOUAGGC@ECGECAKCGBIAEGCCKIIAAAEKGYa@EKOKYCM@GEEAEIEEBEAOACCIECEGAAFEBACCEIEEEIBECK@GGGCMBGBIPADGAIIBJCFGJGDAH@BLHCLKJBBJPALEH@HEDKBCB@DDFAJBNKLEV@LMRCHBREHCJ@ZGPHTYVKDMHSAIDCNKNIFDRIGMOGKGQ@GBELQBMCIAQCKACGAQ@EAIK@EDGACE@GB[CIQGGKASAWGE@KFCAECCGBEFI@AEAU@AAHO@AGCAIYBSFSPQTQRIFONSLmPM@ILE\\GPQTSL]nMPibKFKLMHAFBH@DGHCHBNEJABMBA@CJQDGDCNILCJ@^CPIPAHFJ@LENYRERMZWRWjUrGLIPMLaVEHBH@NFHADCDAFBTDFJDBB@FKTGHG@EEKCODI@ECCDEBELBFJHQRC@MGCGACMGMOOGMDEFS@ODABQEQAGHIDOCGIAC@CGBGDCDIPUFGJGDEHANBVEJaNIAE@CDAHBDD@JGDBCRAJEFEL@HFBDJLBJFLED@@@ALGJDLUAGHAFA\\GJ@PCD@DHNDRDDHAFBBF@DRL@BBFEJCXFVCNIDSCEBGFCJHZGF@HC@EDAJI@GJBBJD@FEFN@FHPFVDNLNDFDZHCHID@FAHUZUJGH@PDBNBHDLBLRCLKDCHALEFDJDHIFADGHCFDJBJDHAHJF@B@HGFCFBJGJ@FBFHFBD@PBBFADBPZHHBF@BCD@HLZF@JCHAPFF@JEDIB@HBLEDDDHCFFP@BGFCFHJBDADGFLJNBDP@RCDGCEDCRER@DLFHFPMNCDGFCNARINEL@XBDATKLIDCXHTCJ@DBDBBFAHFHDHLCJ@BGDBFDB@BAC@AGPABCHDFBNABB@FJFAH@FBBBB@@CJGFQRQVEPBDH@PFDF@FCLIJ@DBDFHHBF@LENF@BCFAFLH@B@B@BHBLBJGTJ^@JPFCBBADEBCHGBMNLLJDLJ@BABIAMFFNDP@FEDC@GECHE@GDAD@FABUCIBLK@AE@CEC@@BDD@FCDA@CEMFGAIBEL@JDDMBILKBDDADKFIDCBBF@PFJFB@BEJGFCHEDG@DHCHEB@BDBJCD@DFGJBFAJFLAD@BDBBFFFBDAFIJAHBHDLDHFD@JBH@PBBLDXBPBB@HEHCTDBLED@JFF@TMPBHALAB@LCHDDAHBDAJGHADBBFFBDE\\GHGAEBSJC@G@OGOAABDDJPBLBFEFYJ@DCPKJ@BJJDHNHJDHLTRLLBHBJAHI@IAIDEAQCWGHVJFFHHJAFejETCHABS@CHBDABGCSDMLEPFDLBFDDFBLBDPFLFJJPRHD@DGF@BFHADCBUBGF@DPNLFVDTRDHBNHPBFCP@JHTDFHFEDKAABYhCBQGGACBK@SRGLEP@FHLJJFNHJTJLBJR@DAFGDBNAB]PI@CB@DAHAHF\\AJBHAXFJ@NAF@FLVAF@LBNEVIHENCF@BVXDNJTHRRPFHHFNJNNHDJJRLDFNJPHJF\\NHBRHLJLNFLJHPVJJNDJJNBN@NF`RHHZRZ@\\F`@L@FBLJNRNJHBTADAHG^GJB^JLDJAJAZCHDHF\\J\\DNHLDNBNCH@RHbVNFVDTBPCR@JCNGPBJFFLBTBHFFPBLHPBJFRRBDAN@RCFGDK@EBMLEJ@JDLRR@HAHCFCDPHTABB@FKBKLGNQDIBCDAH@R@LIBENID@LBDAJOPMPWDCXIJG`QBGEM@A^@HCBEAEMk@MBAHCbENIDAAIEOKQSCAAACBGjO@C@CCAKAK@uPI@EA_QGQECDGMI@C@CTEDCBCGWDCF@L@RIDCBE@OBCZ]DAFB^RHB\\EH@fTH@HEL[BAL@V@LGLBHAPShsFSFBFHDBD@BAAGGK@CRAhQNB@AACOSCIAk@KFKNOJIRQJEPCP@@GCGFQACMOAEBGDGdFJBLFDD`f^lHJTLPFL@XIJI^[PCNDXJHAFADBTDF@BDDA`JLAJGFGdW^MRERApF@FFHDNFHFBT@FB@RDDHTLFNCDBFHBHJNNTDJLPTNBFFBVBFDbXPHLHHJ@ELKFG@EFG@QVOHKAQBCEE@CFAFCLENCPMLCNEDELGHEDMDEHALGF@FBLATKDC@KBEJKCAIAAADCBG@ECCEC@CBEEODKAEEIGE@ABGACECAEFIBMAIMYKOAEHOEC@SDCXGJIAKCCKCGCAC@SDC@CHILEAAO@OS@KHG@MFQAM@ELIZ@JAPKLELGLKDQGUEGAGHBAGBIHKACEASAEAGO@E@SBO@MAAMGAE@YFEFMRQ\\UJKIW@GB]KQKKEQ@EDCNBFEDID[BCHCT@DCDODEPMH@HBHCFOJMDANLVFF@FCBQCQIECADMCGDGCKBELINAFEEQBMCIBGFG\\MFKDQG[BQSBCC@CFMACGCGKCGCA@WBCICCAEGCEMACIAB@DABEACC@CBEJG@EECDGAC_SO@MGI@KBGFAPQJEJM@ECSaFO@IACSGAEBALGHIREAIEEAECSBGJKLMAmDGHEH@JB`NH@@ECM@QRQDG@GEU@EIEIM@MJGCAK@OFCBAAEIY]OeCQIUOKBCBANDDEBG@WAOJI@EEGCMGACCIQDOACCIBIAACACCEG@CAAC@CDEBOAEBI@MBEFIDE@YWIEEIOAQMYKUCM@GFABHZ@DCDOLMDC@KCC@CBGHCFDN@HBLADA@G@K@EC@G@CCEQMCKGI@GFMFEFADCBYAEEMBALKFEBC@IDINGJA^JDDRDDGCCAEFIDAFAN@JCBKEKBEDCECCG@ACGAGCEQQ@EKQCM@IDEFC@C"],"encodeOffsets":[[104681,25508]]},"properties":{"cp":[101.546046,25.041988],"name":"楚雄彝族自治州","childNum":1}},{"id":"532500","type":"Feature","geometry":{"type":"MultiPolygon","coordinates":[["@@AAKKGEC@IGETD@DFBJ`G"],["@@@FDDFBFANGJMLIDCF@FDDDBFBBJABABCCA@CLADA@CBCTINKBA@ACC@CF@L@PCBC@ETMN@DBF@DELIF@JIF@FCRO@CFGFCLETEF@FBLBDCEE@CNADADEBAVDTCR@BABACC[GGI@C@CHCNEDA@CAEWUSCM@EC@ABGXELI@GF@bLJFPLDPDBPEHIDJRDLLHTDDBDAHBDAHDHH@R@TBLNFDNDFDFLPFDHHHbVNLLPBH@FCJKBGD@FJLFPTLFHBLON@DHTFDLZFDFJHJDRLNDLLNHPJFJ@FC@ED@FBJF@FFHNP\\@PEH@`ZF@BABCEWCKOK@OA@ING@CGEEEQGM@CH@PGPMNITGPADBAFDDJB@PBNRXRP@AAC@CJA@EDCJDLJBAD@HBAGFCDGDAHAJCVgDAN@RJB@ACKM@CDANDJCHED@\\YRGLAJBJHNBJATILK@MAAGACC@E^SPCHDFVDJJHJBRGFEBE@GCGAGFCLAAG@EJADEBEACAEICKCM[CGAGDI@MZFBKDIJMFCBEBGBAHJHAJIXc@G@CFGFAFDF@DA@MFQEGHAIEACBMCAEBG@OKIAEIGBCC@EBEAEDIPGHK@GE@EDC@EMI@IAIGIMCCG@SHQDGCSMMCOOEKIGEK]]ACBGEGEEGBGAUMCCAIAAQES@CCCIEIAEKKAICE@EECCKIIBGAEQKQCECCC@EDOAGCABM@EDE@AEGKE@C@GUKYGAGFK@EGQBMEOKKIC[B[CGCMAIAgBKDEHE@AACWCKEEI@OFK@_OYIIESYEOHO@ACEYMGAGCCAMIMMCCBGKGEGEM@GGI@IBCACBCFEBEDE@MDEEQJEFIDADGVOHGDEJG@EBCNEBGFEBEJGHCDEDIBCBGIG@EEEC@ACHBbKXULGVUD@PJHBDCNQ@I[QFIDCNGJGBGGOBCJECAYMI@AKGEUAKAGCCEFIBM@GS]CUCACDC@GEAGBCJ@LBBAIM@QAGGQ@KBSCQCICESQHIJILFBCGOJGBMFKACEE@CJEBE@CGK@EDADGK@@ODGXOAIFQEIQUCQWWGKGUEGQIAIECKASGQACCAADGHKBIA[BIDExaBABKFGJIHCXALDJFNJRTLDD@NILEDBN\\@JFHRLTFFAHGFKFAV@DCCASAEM_KAEDCVIFCBIEIAKBCF@RFNAHBNDLFFALOR@PCHFF@@AS[CIDCFC\\DDEBGCSEGGCCEVKLKHK@KCMUIEEACPUDGFiOY@EDEDOHKHHFJDDFDF@PKDGRIJEHAL@JET@JEHIHED@DGDAJ@HABIFCBADBBAAC@C@EFEFE@CFAAABE@EJI@CAABCAAFCDA@CD@BKF@BEAEBCEE@EEA@EUKA@CCIGAGDECCDEEGDCACAA@EAEAKBGJIBMNKBELMAIDCBINGBEAEJC@ECAAABIAC@ICCCIDI@aDGJGDGOY@EHG@CGKIEAEBK@I@ELI@EDGBEHG@ADA@ETWCM@C@EIQAMBGCKDCACAC@OCCK@KEIIMYQGGOCCCE@EDCBCHAAEDIDQGMFO@IDECCBGAGFMEUBIEICQKKEAK@KFG@CAEEFIPGFG@GKaBC@GDIBKFIFSHKBGAGECIKIGAEC@DIAKN[NKRGVAHBBFANBFDFJFRDPAFAROF@BBFDJ@FDJ@NJPXHH@DAVBJAD@BBHJDFBDADIHPFFHDLZCVBBFLPP@DADGEED@FFDFH@FCBECCAG@CRCFBDJH@JDHJFFBJADCFO@ERAD@DCN@LHQFDDRHJ@FRPVHP@HJPJ@JHFBBABBBHFVFBNAJBBDFBDAAWDCJCFWDINGF@FDFBDAFDRPB[AICAAE@GLGJ@FBPRFBHD\\^DBF@HBLKFCJ@THHFHBD@TMLEDC@IHWBCCMKQIVG@IJC@ECEGOJOIEGUKE@EDC@KEM@GCSICHCBOKC@G@GDCCGGGAGEICIGGAG@EFCHKBE@CAGAIKMIGKKOEUGIEEICCGYKCGMSYYCEEWCKCSKMACDGVOKUAUCM@MEK@S@CEI@KACGSBKCEECCAAWAAEAEC@CPOBCAAIADC@GFG@ACEBGAAGAGK@AHCBEBEAIAEGCK@EAGBC@EKIACIICGBAHA@GACC@EC@IHIHGNEHGDK@GDCFCNCDCBKKGBADDHAH]ZOTCBGBIIC@EDEDGRINEF[NILEJILULADEFK\\GLGH[bYNADCNMLENGBOCGBIPMFCFADBJCFIHyvGDKBEBKHADCNEHOFGDCFCVCHIFMDIHEAAFA@CIC@FIA@GBGFMII@DWCAC@MOBMGCAGECIECIGGCEOKAC@GE@CCKUGMCG@[HORQBCAIKa@ECCAA_IESGMEQU]EAC@[HMHBH@DCD[NIHCHKLITQLQVAF@HD\\ADWTMHKN@LEZ@\\BDNHHHBD@F@HCBCFOFWHEJCLADKFKBYDCBENURiNE@WBWHIBEMBoEAEIGWCEKEEKMMMUAMDOAKFIA@EECICKDSCGeSSAKCQOMGCCEKMCQ@OBQFMICCCI@OCAG@CAAES]BECC@EAC@EC@CIDMFMPSVSAEaSOMC@IDKEIBCAKS]SSGaGMAGEIYIKBCDABCAECILGFG@YCKCCKAG@EBEDE@OI[@KECBGDIJKFEJED_DEFDROL]AKAMNE@GCQFQCGDCDGXBH@DIDG@EDAFCTADGFIDMJADDJFFADIHQLCDHRGFKHADDJDDDFBHEJUJEPCDEBSBGBEDALUJMDQE[@MBGDMRFN@DGH_BIBGHABI\\CBKAO@MDGLIBGFKDAD@NEJ_NE@QEUEQIGAEJWNMPMH]ZEHGFI@QMIECEBSEIEAOAEAKfINMJED@NDDADGDEAEBOTULMJKREBIACDCBU@ICAA@KECGBOAQKAEGKAG@QHQGGGCKI@KAIEEEMCESKOEMKC@OHMBOKAEBEFKDMHIDADEFKLIHEF@JCDC@CCCUAEAEGsCEICEAYBICCC@GFIBEBADCDABKYIMEWAOCEBQRCFGDEBIHALGH@NCHGFBFKZE@ACE@EEKEEBIHE@CEABEDG@IHMNCDOFMAUMAEC@GDGHIDGFM@CDEBKCSAEDEBIDSDkXCDMDUDSFIHCLKPAHEDGNAJAJCNATBF@JBFALIFWVEDEFIFKTEFSb]PILCJIDOBQEMDOJAFGFCFGDEFOHSDKAKGCCMYMIEAEDIACFIDC@@AC@GJGFODSZGDMBEDKPMJK`GFAHEDSV@BJJPDDDJLDHNLJNJFTGD@FFBH@HGRBFNLHJ@DEF@HCJBFGL@DKJ@DFFLCFBDBJDHNENBNHRFF@FCBDDJDJBJBH@RFDKBEDCBAAABABABHDANBP@ZBPFDDF@LFBHFC@CBAAAB@ACB@BAB@AGDCAEBAFACG@KBARGR@\\BHDPBBADEB@DDHLHFFHFDDJ@DDDB@DFD@PADBBD@FIJ@FBBPLDFF^MHKVCLLLJBFDFHLJDH@HDFMHQ@G@EDIAADCHEBCFAHFLQLCFIFSDMAGDGBCLNNBDIBEBQA@DADIF@DHBDD@HJN@DCBEAC@EFKSEC@ACC@DKJKCGEIDAIGE@CDCHAAGDCAA@EEBIBCEAIAACDECOHGAAFBDAFGFKCEBACIAKGOEE@G@GDADIFC@KBGAOFK@OLEBEAAHCB@DEBAHDF@HJJBLFJAPFFBDBBBFADGB@FADE@ADCBCD@DBDADCFGNFDBHD@@H`BDJFDBDB@BCB@DAF@JED@JJBCB@HH@HHHBTDDJFBDFF@DCFM@CHGBED@DDF@DCFCLF@DDBDAB@H@AG@BVDDLAFDFJAHBDP@DBDDHBFLJFBELEBDB@BDBAB@N@LIHCFDPEF@HFL@JEHEBA@GFEJGNC\\@LPFDH@FCFEDCN@CMBCDAJCPAJCPG@@NLHFX@LCLQHGJ@VBRLFFTABDHDDFHBHJ@FBDHDDDAJCDBDADFLDB@F@DB@AFFHBF@F@FLNDJHHCFBDHD@DDBBDDB@DADFFB@@DHHD@DHF@NEFCDSFCLCJ@FFHXN@DBNAPDXCNDFADCJ@PKNCL@TEF@LDH@BALPCJDHJTCFHJFJ@NPPPHHLJDDD@RKJJR@HIR@JEDODCDILMJAHEH@DSJ@FDFAH@JDFBLCFKJ@DMF@BADOLAF@FDLCFALAD@FCFDJC@CAEDC@AHCBEACBCF@DBD@BMDMLCD@FCBKBABEF@LKJE@EB@JMFINAFEBAFQDSDM@ICG@GCKCMDABO@C@@FCDMHAD@JCJ@HDJNRDTBFLFBFXHHJHDMDC@CDFLDF@DAFKH@FABIFC@C@@DFHOFCDDDFABB@BCBE@ADC@KFAHIFABDH@DKDCDFJD@HEB@HJBDADFBADEBCAAACH@FHF@FFF@DHBDDD@DBBNADEA@DF@FFNHF@BED@DDD@FHFBF@D@DDJ@FBBDAF@BP@FFFBBDABFFLDBGC@@ANCNHJ@DB@DDFLBDCBGHAFEDBF@VPDJD@BF@HDF@HA@C@ADEAGBIECB@DDDAFDNIJFLCZEDCDMDEDCLILCJGHELCBANKFJ^B@^D\\HXHTEF@FDBBFBX@TBTHDFNDBBDHBDBF@DCFKDMAC@MCMBKVAFCJAHLBFDBDED@BDDHFVFBADCPBNHH@NGJ@JCFBNJH@NUZ@DCEC@ABATINAXQ@AOO@ADCZKH@TLJBD@LGHAD@JFN@FHTPTAFCCIFKJAHKFSFAFGFCNFTBDBDHLBHFHCHEP@BABGDEDAHBVL@DDBFAHCD@TRNFL@JCFGDCBEACCCYCAC@AHCJAR@VCFEBI@CFCBE@EMEIODA@CHAHEFADMBEGSCCAGMSLCFGAEBEHE@AECEOBAP@DAFCDE@AIK@CD@F@JNVPD@AK@AD@HBJFFBHJ@HAFID@DFPDDFHRLPVDBNFRCDBBBBHANBDLDHNEHHFLNIAADHTDFJBFCZFNGPAAJJFFBRCDFbRHFJNPALCKMAYDAH@FAHKBC@ECC@AFCBSBADGDELEJDPBVJAFGJCL@FHFND`ED@FD@DCB@BHH@FBFHB@F@RFBJHRDFJFFDDPHN@DDVJF@DAHKRSZCFCLKLEDGBAHAJBRAFSAC@CH@JDJHDLHDR@BBADGDI@AA_H@DKDAFBDDBLNNN@DGHFFHDFLRHRJ\\LBFCPDBFHLfDDHD@DDVLLTNHDLABD@DDFPJSFCDAHDBLBBBBXBBAF@DHJDEF@BBAHPPBF@BIF@FFNAFKNMJKAEDCD@L@LJdJDHHAbCFIBSBEDIPAJBFABGAIGE@CDBPANSJ@FBDBBCJBDBLBFFFDFC\\BFFDBB@LDJAFCDIFMAAHGDWAC@IRCD@VPLL@JFL@LFBLFJHJN\\@HCDCNBFAFDJFD@HBD@FNNNFJAHGDDLXJFJ@HAJKDOHGHBBDGHBDD@HEDBFNH@DCHCFBHLJFDABC@K@CPAJFD@DQDATARELBFDBD@DCDKDCBBFDBBDABEAABBLHFHFDFLDHDFFFJ@FCNALIXID@BBDNFDFAVBLFB`GHD@PAD@DFJADEFKBGDAFDJDBPD@HAD@J"]],"encodeOffsets":[[[105527,24614]],[[105760,25244]]]},"properties":{"cp":[103.384182,23.366775],"name":"红河哈尼族彝族自治州","childNum":2}},{"id":"532600","type":"Feature","geometry":{"type":"Polygon","coordinates":["@@BAAM@EJKDMAGECHMDUFMHATJJ@PCXBBA@EBCJADSHMAAMECAQ_BCRAPG\\ELGPKJCfiJILEJINCNBLFFHFLBLCbCLCTI\\KpAXFFBHHFFRFFJ@NF`QHAH@BFAbFDTDHAHEDINIFCRA^@^B\\FfGfO`CPEXCJCRMPQJCRA`HjBNFNHHHLRLFTHpFVABC@GBEB@DCBBBCBB@ADA@BB@B@DAFDBA@AHAPID@BCHAF@F@NGLCBA@MK[AIBIHKJGJAlJNAZQZSdSPSBUMQSIOSAGDEFCBG@CAASBC@IM@CBAL@DAX[DCAE@AEC@EHAZBDAJGFU@ILYFGDADABBHFVBDC@ACGDGBADFD@FC@CE[AKAAA@AMAAGAAA@UCCKCK@EECCCBARCDG@EGIFCAABC@@EAAEFEBAKGMAEBCD@F@BC@ECCACDGAGHINGDELaJEVSTIDCDKJI^GDAHKJEHDBDHALARDJPJD@B@HCBCBE@GFAHQJ@PL@JCD@DFDJHLDBHCF@H@TJH@RU@EHI@EDADDBADBJEDC@IHCN@F@JMHAJBFADIFGNEF@DBD@DAL_FINK`GZCH@JEX@VMLABAFCJ@LCHFHJR@BD@PIPADFJDF@RNR@FDF@LAJ@NDPHLHFJJ@DGN@FBDDBF@NCJGH@RLTDR@JCL@DHHBBFHBXCFCHBFGFALGAMBIDGCODAH@@QBQFQJWEUDQBADGJMFAFBDHFBJ@FANDJH@BHHLHDJFLLHHBJA^ERGN@lXHFP@dGVMFKCIOOECCECODENIF@PHFBLANFD@NETFHJBHJRAPDBHAFBFEFEPCH@HIJBJGDANFFHHVADBLDH@DEF@PEbDLNTRPJBR@jUH@LCNDJDDFTDXJHBJAB@AAQCAEDELIDKHIN@DBDDH@BA@CLAFGHAHENCDIDO@QAEBGAKBGHMXMFG@EFCH@HFJANOBIG]@GCAIBGMLGJBH@JMDAHIBGFARUJCFEFGHSJkJAFIPOBKFCEE@EPOLEdELCFEDGAKIEK@IBQCXePO@UCC[MMB[EUOGGGM@IJm@MBSDMT]FK@]ISEa@cKaMaawAIFUDGVKJIBICEKEYIGISiMKM@MGYkCMGIICeEQE[SWcUOOBIL@FHPJHDJ@FAHUR[FYDUJOJIJUAYQG@GFEFEVEJGHKFKByCOEeQSOCIAeASCGGEwAMCMCMEEEAIaima_YGCIBQHCDQDKOODSDSAMCAANEB@JBJALEFEJCBCDADBD@LI@C@IBC\\EHEDGAAGEEGIAKDE@CCAEBEFCPBFCPODADCHK@CMGE@IFIKC@KFCF@HHLAFIFCHEBG@IAE@GA@KGECCIBCAIEEGIGIDA@ACEE@A@CFEACQB[CCGCAEKagGOE[EG[K]EGGAG@KJ_RQFG@CDGJEIEACBCEE@GSBGBGNIDG@OHKHGTAROREPMPGHGBOJIHKZ@JALCHILKHOBEECKIEMCKDIJWdK@[RCJ[`EJALAFBVCFCHUNKJEPCBEBCCOOEAC@GKEMGGGMY[GEeAGIF_GSIUMOC_CIEII@aFODcRQB¹MAOAKRQNG@OAaYSCgkWMiGEKASCCoDKAGCEEEEAMCICaIQE@I@CFAJGBIAKDEDOZgIMEGIAKBSEOCWEIIA[BaIMEEEGIEDCLIDMAIMBUFeNGDG@gJIBECO@KLIFQPoLSLMXMFYBOEUOMOMaEeUMG[EMCIEKOO]G_QI_CGGBQFQBQCEWCUDU@mKK@KHILKHeDKDYBBCCABCF@BED@CCBACC@AAABCA@CFC@@@BCACGIEHCCE@E@ACC@CBDHAFHBADH@ABBBAB@FABGJAFBBABBDKH_@KEMSOI]GSIMKCUGOOKSECEAMEEYIMI]WOIYUYI[GKU@MEEIKIMAMDe\\@RGLEBCDGDGFIDK@MCK@GBSNQHKAGBAFBJAFW\\@JAHCFDD@DDF@FFLDPDJDDAHDDCHBDHL@DBFBALRBJ@JGV@JCDKFSNC@GAGESGI@EDKLGAE@CAIGQUGCEAOQEAI@KH@HBFDBBJA\\QQEACBEAECE@CBIFCJEXIDCDBT@DCBEAACIAMBEAEUAGAAABEAIGI@IO@GGOOUEQI@QGCCREKGM@CDC@QB@FEPCDIBEAIECG@IIGACDEDQH@DBFDDA@EEGEC@EFCHFBC@COOEKAADUKYGCEEGOCJCBEAICAG@ABCAIBU@CGGOWMII@ECI@ECAAE@QPEBOBQCIECEAEBMAEGAUBQHMLM\\BLCJD@BFJHJLFDBHAHGLETEJALCJ@HADLb@HEHOHEJFFDBH@LEL@FBLLDRFJAJFVENBHAHDDCF@JEPHNCRCJBFGBADCD@FDFDDHPRHNZJJLFL@DD@PBDBDCDDLAHBNJR@F@DBFBHCDOT@FCB@BGHAFCH@FKJ@F@JALBFJFHL@DGH@FPZCHIHCH@bCJDJDD@JBDAJBBDB@FIDBFAFMHAJCDBJKNAFMLANIJAHBLBF@FBBBDCDFHCFDDCFBHJHDDB@VL@FFB@FDDBBADBHAB@BEBAJC@@DCBEDBBADBB@DIJ@FAFBBEB@DEFEF@F@DBDABCAABEDAJGBI@CBCHC@GFGJIFS@IFK@GBIFQJCHOLKCCCEIEEAAABGLANCF@FPZEjCHOVBDFFVJDN@LGLKLULDFHDFHDTAHCF[CEDCDDJT\\@BE@GEODQ@KPEBKEUEMBQEE@ADBLFJAJEDUJCDBF`LFNTBDBABWBGDCJGHEBIAICQKEG@IM[CACBUNC@KCQSMIIEKCWBGDMPCNABwbCFAJB\\AJGLCHBBDDDBN@THLBFDBJRJFHHVHLXXDRRVFJERBJWPCH@PL@CHCB@FHL@DAFIF@DFFBDELANIHHPADKEIJGJTRDFDJDRAT@LHRBH@RJNABKAI@ADBHHFD@DCDBDVT^@HANEJDFHDLBVBHFBLJ@ZNDBIFADHPAHIHMHCDEJ\\R@JMRCDGAOIC@UVKHWVaLGABDD@FF@FJHAHADCJCFGDIHAFEFAHMFAD@FIHCFGHUPCHCBEJIFFRCF@NCFAFEFADBDAD@JHJ@HFNFHLHAHDDNNNJDBHDHBZNDF@BGPFPTZJFZJ`PL@PEJ@FFDLDXBBF@FGLChAJBNBHD^F^CJHHJFNANHP@HELBHZHVL@H@DLFFH@BCF@FANDBBHCP@FDDFDRDRLBFAHJJDLFD@FDFBJLLBFFJDJDDT@RFBBBJDDVNHBHAFFFHAHBD^^DJLJFLPPNDXPHBFCH@TGH@DDJNJHJBJ@NCVIHAHMLEJQFAJ@JBNHZLVHH@hTZFLFHHFAHCBKJ@`L^FFADGFCFEPOVgPGHKHIFEDE@GQWSM@IAKFIFCD@FJLDBGV@D@PKJHFBBCDBBFFHHBJ@JCPKLMRGF@NPJBNCDBNLbDHD@RRJPBJCVDX@RFV@H@LJ@PKNELBDH@FD@HAL`JJHF@HDNDLHRBDGB@ZHR@ZDJCHCNAHCF@BHGPAFBJDBFAPCJ@J@LBDDDFFRHJF@"],"encodeOffsets":[[107077,25060]]},"properties":{"cp":[104.24401,23.36951],"name":"文山壮族苗族自治州","childNum":1}},{"id":"532800","type":"Feature","geometry":{"type":"Polygon","coordinates":["@@VDLCLGLKLGNCZ@RdEL@nMP@dTPL\\NDFNBJCDDN@BFL@LJBCDBBDNFDDH@FFFA@CFCD@BF@BJABA@CBADFDLDABDLDFAFBLEHJBCHG@ACC@EJIAICCAEDIDC@GLQBGBAF@HFDCAKHIBG@EFEBECKDE@IJULOJ]DQEIBAD@BGVU@IDKDGBKBEEMPWXOBEDCH@HCHBFCBCH@DCAACABARFDCCWKQI_BGBCV@dNFALKF@FDBHNBFFDBnGJGHAR@AKWUCQGQG]MM]IYCQ@UHOEGSYm@MXSPUH[NULIJKP]BQ@OJMBIGGgEIIAKRiJ_FMLSPKFMT_DWLQDMMK@E@SCQMOIEBGXANEJENCJGZIPUHCJDbNRAJEDK@GGgBYHGHKLIRGPAHCHIBMAWBMJGTKdCFCDIAICIUaEQB_CQWgAIBYHG`SHa@SBGAsNWDORATFTBHE@YNGPEDIEOGSKKEMIGEIMGQA]FSLSFOECK@IPKLC@GGUAKBIDKHKLCHIDKCMKMYMGGOKAGFMDOFuBaDO@GUQCKAeCSM[D_J[VuLM^GXDJCN@DAZkJGXONBLABK@KIMBOHUBMAGGAS@SPGGI@MBQ]AOI[_qQI_A{DQDGJCJBRAH_TQbKDM@mIOI_UGAGEKBOJGP@LJTPVFXBLGFqR[FUHgHcEgIUAQCSQQEWEASB]AMGQIOK]SOIcKO@SEKKSGEDGJKFk`STCHEDMDIDGFGH@JL\\BPdhH\\APIJoPKFUNi^E^GJOLe~OfHJJBjA\\DHFJNBTEJLRJ`XFF@DIBKDGJEbJ^GP@RWBcEuLK@IHCHFTNRVDJ@HBBFBPADMXER@LFJCPGJG@CD@TDN@FGDKAODQV@FAFC@GAEDABHbANCR@HERANCNBRFNPPADCBIEEBEAOFCCUBACCAEE@GE@ACE@GEE@CGECMEACCCCECBA@AACEC@@ACACC@GAAICCEEEC@ECG@CCAECACE@KGCA@ABC@I@ACE@EEGBICIBIGEAEBECC@ADC@EAGDCEMDMACAACC@AEE@EEC@CCIBCA@FMA@A@CFECCEBCFCBK@ECKCCBCFCAAECA@AIEAAAA@CE@C@@CABAA@CAB@CAA@AECBCCABCC@@AC@CKC@CIAA@AGGBACA@AA@AADAAACAGBMCGE@AC@CEIEACEGCAMAIKS{KSIGeKWKQUIOQcOIOC_@OAOM]aMIQCSDSGSGeWUEaQSCUB_TSRKD_EeQS@UPOXMfO`OLCREJGFGJK@oYSGMBIFE@GAGBC@UBCACDIGEGBAGAACCA@AEEAAAECAAGECMIEKAEQA@AEA@GCBCEACGACBAAEDCBA@CFE@EIE@ACAABCE@BCC@AAA@AACB@CCBAAABC@@CADCBCEEBAGABECAB@BGDG@G@CB@HE@BDDDAFIFAFSJAF@HIHAFCDCFBBMHG@CAOHKCAKCCBECC@GCI@CAGIGg^UJKBKJERAJ@FDH@JCLCHADBHDH@HBHALITQNANBHFLNHJHLDFDBDDF@RHNDFLDDHJLPBRCFDBF@FEJCJKNABBDMDAHEFM@BLODCD@BDF@BE@CAA@CB@BBBABICEBCHEBECI@@ICAIFCHCDE@ECEMEGEAS@ICcWGMEA_JCFJZ@DC@IFOEA@C@GFMFG@SJCLIHAH@LAHO\\DJGNCP@HQVCLBRCF@HSTCJALELFNAJDH@HCHBJALBNJJFBJHHRBHEL@VAJJBVHLNBJCP@HFFJXDDAHDHNTBHCDGNAJKNSNGNEB@DBDKFENAJCFANHHNHFP@BDABF@JBFNHLVJ|HLdChVXRj~THFBBQXDDP@DHAJBFHFH@BF@RBFH@FFNARQTANEJ@JCHBDFDBfBJDFHFPFFL@H@J@HBDFBHQ\\BXNJJ@JCLAVHLCNALEZBFARUHAAC@CdQVEPANINAHEVKLCJFHHHLNFLFHNBLCNDHHF@NCF@FBFFFDHBPCPBDLDEN@FDHEFJf@JAFEBKBWDDBD@FDLJGLAFBFHLNBJHHBFDDFDNJRFHDJHDJ@PELUTBBFBHAD@FJBBFFDHBHLLDFCDADBFHLDV@J@B@PBRBVHFCTCVDFCLAJDFAR@ACFEAABAA@@CFA@CHENCH@BDDBNEJHHJDHAHKR@JLZDHHBJ@DBFAPFJ@DBLBJFCTBJDNR@XHJAZIL@JDJJVAFDJNDDBJ@JBBHDFPLHAJBDD@DADDD@@DB@DHR@EB@BHABBB@HD@ABBD@BCDBDFDEBBABHA@BJBBBF@FCDBHCBFLBCDD@AD@B@DA@@BA@@DD@ADB@@BA@ABBBDAHA@CDB@CDB@BBEB@@DD@ADFAB@DCL@FGJ@HCH@FDL@HEDKPQDEJKDUAEDMNCZUH@R@RFFHTLRP^RJ@NBXAHANDFD@BGHAFCDAJHLBJB@@GDAB@BBD@FCACHEFBDAB@@BFFLBDHABAFBBF@FHHCBD@CDBDABEuJITGhGPA`FtD"],"encodeOffsets":[[103594,23092]]},"properties":{"cp":[100.797941,22.001724],"name":"西双版纳傣族自治州","childNum":1}},{"id":"532900","type":"Feature","geometry":{"type":"Polygon","coordinates":["@@CJQBGDGLGPCBC@OGIBILKTAFAFCDG@KGMAGBGFQRGBK@cCMCME]E[GQAKECOAGGUMIK]QGGEAOBCACE@]AKGGBQIMIEQAODGDG@AD@FB^M^FZNPLBDDNPTAFBDFATDXDHBFRLDL@HJRDL@V@J@DCPJLAL`XDLFHBHHJAHDFAFDDBDGH@DFDDHCLBFHBHJDLLFBDDHEJ@N@BLLFR@ZHTADKFAFCDSAMBAPCDABS@EBECG@CAACAACBGDCAAAEAOJKAGBCAE@C@MLQBICEKGICCC@GBE@OBA@EGGEACAMEYCCIAQEE@]JCBCHKbAPD\\ELEfCDI@IFQTADXFT@DBHDTPVHJDBJGNAPCDMHGL@HTR@DCDKDSLKCEAOFO@EASIGGABBPEJ@NADMHAB@TAFKJCNABODGDIFCJ@XEJEFQH@DHL@DCRA@OKOCIEIAKEK@OBC@QKCCABCAYQBSHSCEGEEIOMIMEE@IGICIEE@CFI@CE[SBMCKAk@GACC@CCACDBDABE@ACCAIDE@EDI@CECBCCG@AC@IG@AA@CJICG@CCAAAEAEAGEKCIBEES@CBIAIHOPAFEBGAG@GFCFSEGLg`EHMDSLkJWB[PUFABGNCHCDGAKEKAEE_AAGG@MTGDELOHCFIFCDIDEHKFIXEDEJEDKNSREJOHKNSLIRIFEHCBGJGRGHGVGLBJERKLIFC@]@MLKNINERKLEHGVIRGHSVC@ABEJ@JEHBFBBD@LEF@DBBHCJCBCAAD@LARANCFCJEDBJD@H@HBFEFCFDDCJ@RMNCHCHBFCN@FJ@HCLC`DNRRBJEJGBCDIZIFQ^BDCJ@FJN@FG@MCI@ODEJABOCGBEBGLMJEJIBSHKHICKBGCW@QGCGAKCCOIEBE@GGC@AAEGAAACCC@HCBKBAJGDUAOCCA@IDEBCHODAAEQGKAIEEIICGIG@CEO@UIO@QECBQbIHMRHJEL@HPNFDBDCF@RCFQLCFKVCPGDE@ECCC@CeAKBWGCBGF@NALBDF@BDGNAJBBHCBBDVADGBEDHTJJ@FBNCF@BCA@ECAQBEBG@QBMHCAO@SHEAIAAAGBS@ACKBAEICAAA@ECGAGBM@SJCD@BDDBF@XCJEDGBAD@BB^CFKBAJ@J@JFDDLBLEPALVNHRUDKDADAHCJADGBAD@HBNJPD@h@HBPFF@DCDEAUDGDCVCHCHEDAJBDHFAFGTIDCLQNBLILCTERCZJJ@JBFHBPBBREN@LADBI`MHMLEFETIJGBBBLJHH@PAHCFAHBJDBHBJCNILFH@VCHEACKGACBIL_FID@ZJ\\HR@bCLBHEFBDDQbMlEJG\\MZMhOZAZG^ENYpKVCDELGHCBGEcMIAQHCBKACAGA@HBJCLCjEVDHJFDD@HAD@JADBNEJEBCD@BAJBPGR@HBLBDF@BDBLBFCJHJ@DGHAFFRHJJDDLPLFD@JCLJDPPB@FAFFDBZETE~@DC@ECWC@OBCABCFARAFGFDJ@RADHXHHE\\OR@NEFERCJMJEHAH@DBHLBHUHQ@SPILADDJAFSZAF^JJPRRDBJBHFDNDFVHFJHDVBFHLFBDDNBDLANCH@ZVPA\\CFJHFV@BFBLRFFJBF@BIFODMFEDAF@FF`R\\JDBRFHBBDANFHCLADMB@F@HLDHDDdPFLRHALFBTBFGD@\\BDCLAN@NLCJHDJBPJDLFDBJHFNBZVDN@FBBRRDJHFNBALPDFPFLFRILAH@LCHGHSJAB@HJHDLAPGNHPCbBJETILINBPAJ@Bn\\bLHBLFXNnRTRJ@NJRGNBF@LLHP@TFJCVDLDFbTTARC\\KXUDABEB]RQDMTIFAZBBDHLD@FAZPRFTDPHXB\\GFEDEBARAFEHIHGJA^Dd@XEZ@JBDD@FE^@JDBN@VGPGBCdWJM@EBENAPAJGRIfIpYH@VHJ@JLR@DBDD@P@NERBZJZJ@LGHAR@HEHKBE@KJGBEB@X@JCBCCMBCHBHFFBFET@HHNDDFNDFFJTJLR^T\\HVDFHFBLDDPFJJRKH@LDHDTJDEBMKICEH_GOBEFK@IDCJ@JFHBNAH@LLbBFFD@BCAa@CXOPBHAPFB@PGL@FBBAAEGG@CAICMBINEH@DFDNBHFFDBD@JSGK@EH@FCBCAEIICIGGBKDGD@VFJ@tI@MDKFCBCAE@EDCFCRAlFLAFE@GCOOUAGFCTEJKPGBC@MKASBCCC@QFIAC@IGEIHEBABKEKFMFEHAFEDGGQJUHGHBJFLLJBF@FCDE@GBAPARIFMCUCCWDSAIBODK@KU@UAIGGQMAIDEDAJ@NJFC@AEEGGKGCMOQ@E@CFC@GCCGBEEEBCFCBSEKKGMAG@CDANBFEHIDGAM@IFSJQ@SLSTMDE@KGCAEJKDCJ@DE@Co]KICGAMXe@GCG@G^SHCNAF@LDXLJANGHONU@CCECCOBEC@EJUIQ@MBKDCFEFCAM@KCOBODGJKBSNGD@DBJCTBFDPXNAXILA@CBAACJEF@JDDECQDCDKAEFIRDBFD@T@LHFBDDlJHCLKF@FCJLBHHCN@PCH@BBAFALINCVEJERCF@NAHCNCRHJBHCHIT@FBDLLTHNLBHARFBHALHL@AJBBHDLDNFFJAFTDTB^JPJDD@DDBPDFBDDDNAPDBFBbENFVPNDVBHGHADC@AIK@GDGJEVCPELIPUN@RBXCFBJDHNHJJULIDSAM@KBEIQAGBG@MCEAEBUAGBIE[BGBGBEL@^OBAAMHCBE@CIQKAGEGAGGIQIIGK@EFOHKTQL@DAHBRHDAZgBALBFCGECEGS@IDOAEGOAMCGSQUCKEOM@CHEVADABCEG@AHE@CGCOQIIKEOEACAKCEECKAECFONKTCHDBAACDGT@BADGFSfiBEGIEGIEGUXHRDFBJCJBJ@BGAIAGKKSQGKICMGCGII@ALIDO@CZIFEAEAKIOCCBAPBPHH@D@TIFAHBHGF[ACEEAABCHGBIACBGCCDG@KBABKAGLMBC@QEE@IFCAKSCGDGFiCKCAG@IAG@IECCGCKAGBGJIBEACEEAECA@ABCEKBIAEHICEC@IDCA@AFADGCGH@FCDGHEFI@AEAEI@OACBCB@JCLEBCCCLAJKNACC@IFIJCHBNEDFB@DC@ECC@AD@DFF@@BKLJAVDBA@EBCHCF@DGHFD@FC@ECOEMNEJBBA@AKIICKKNMHADGFABCAAEDIO]@SIIHKAGA@A@A@AKGBEDE@AMEKFE@GAEGAC@CJIDK@ECEOEG@ACFORURQHEDI@@AAAA@EBGIE@EAAMBEAGCADOBBHD@ABA@ECCAAHI@KDCGEGBGAECACAI@SDWGCDKJSLCBWAK@MFQJMBEDCHMDONGEKE@CFQDQFCHDDC@QCOMAKIHEBCACGIDEHE@AEODECGCCKFGAA@CJIFE@OEGBIDE@KY@GDC@AAEGGOYCAEBAQACGEAE@EHIAIDEHE@G@AIEBGCGAICIDEHGBCJECGCIFEBKDGLCDKKQKAGCMACA@OHGVIVYBG@EJCDGYGECMCMKUCOEEGM@FE@EICAAHIJ@BIFCD@@GHEGYDIHEFATDJCDMEUDWFIAE@AQK@CAEEAGBCCCQGM@CDC@OHIB[BEHGVBCKHIBI@AOFAAGCKACIEA@GFKFEBIDKAGA@IHW@MBILQHG@ICC@EJITIBEEC@ADELCBQDMF[DI@GCCDCE@ADCHUGOEUBOAGA]AIGGAGOQECMCKE_[KEOKIKCB_P[EI@MPMDEDCF@HBL@DM@GAACC@[JK@SGGIKIAB@HCBQHEBGCSQGIEMEECAEDCAMC"],"encodeOffsets":[[102819,25301]]},"properties":{"cp":[100.225668,25.589449],"name":"大理白族自治州","childNum":1}},{"id":"533100","type":"Feature","geometry":{"type":"Polygon","coordinates":["@@ANFPALBLCJCTQN@LEJFV@FCDFF@XCHFXHRBLDFAFBFCHBLANCD@HGRBFHBHFBABGDCLCJBFFHTFDF@DDDJFDBHFDJNJL@LDLLPBNLLDDFDBHHHADCB@BBLHDAHBNJLBLAFN\\BJJNAJBFNPFNHJBL@NDFDBHA`OFALDDEHADCBELUHEFILIR]TIH@PFFAJDP@D@NLJRHJDHB@DCJBDHLNVPJPFJFDFJLDBFCNALFJLLVHB@BGZClJVLBN@LBHJJL@LDFOFGFAN@@A@GCIDELI@WDGFGTGTFJ@ZKHMAGHKFBFADGLGZKNGAMGO@CAAAKBKFCDKOU@ABCAIC@@GIAIMAGECAAFEAGFECEHMJEBIAGJADEX@FEFKHKj]HKDADBTLHDPET_FK@GAAKCQUESAOCOEKECEG]oCM@EDCBKGcAQDCRIPO@EKBACF[FIHEFAHED@HNRJFHFDLBZ@`VNNFDHBLE@CECCOLADDHDLGBEBM@AC@IDGLGAEDCC@AFBBAHEBCHE@ACE@EFAEGDKFGJEHABBBBAHB@XMBC@ACEFEB@FHD@P@PCNRBBLA@CAK@AFAPFDFHAJFPEXBFALKDEAGGIACDGJCNF\\XD@DAD@FFNDJEJ@DBBDCJDDVDZAXEFKDO@SBKAMBEFIDMJOLOJGACECAAFI@AGM@GBIACG@ID@FCDQCKDW@MHO@GCIKQKGIEKKGKCS@ICKBICI@SOAA@EBCJKHYHER@BABC@MHM@GGMMW@EDEHAFCHS@SDAOGM@KO@CAAGBIAAKMG@EDEAICCJAJJVKL@@IDABCCGLABIJ@HEFACAAEFIHG@CEADCJCVOAIFACEFAAEJG@CI@CA@GEQ@AJHHIBACAAADMF@FJRHF@DDD@TINATLRBDBFADFLHPDHHFAFDFFJHNBHCHBJAdPHAJBJENCB@DIDALBN@LMHBFCFBFADDNFPGDCFSHKAASEIGAA@IDEPEFABCAGJ@@CAA@EDCJEJIBQBCDAFBFCFCF@BCACGIMEMGGMCMCEIEEGEAGBCEBERWAGBGDCACEAECAE@AHENEHGBEAG@ALEJGBIEIHGAGBCLIH@@CAEBGICAACOGODGFAHECIBEEKOEASQaAGBODEBO@CEE@IDELMLKFAJeBIHI@EKKYKKGKCMGAE@GCUBCHCAOK]@MCABAJ@DCF@BEHGJBHCDCKSMKaK[DKHUBGASGMIOKSKKCMAICABAFAF@DADIDE@QHILE@GFMFGRAPCDEBQCG@YC_BIEODGAKAKD[DSCM@EAM@MCE@cCYEKCE@SAWCEEEMBIE@EDAFE@KEGBE@EDG@EBMAWBIEOBE@GBOJE@MDMCSDOCQFQBOFE@MGC@@EC@CAGGMABESF]BGBABC@@@@AJICASBWGG@WCIBOCQBUIUCAABGCAC@C@C@CEKA@DA@ADC@ACA@EE@DCAEB@AC@ABAAAA@ACAK@CAKCKGEAWOAEG@CEEAGCEBKCKSECCEECIAQAcKWK]FK@cKGGKOKGEEBGFCBEBEPE@GAEQCQ@_NE@GEKOG@CHEBCCFQACECE@CBCDCNCDMAAEAADCNE@EEEMGAKCCE@CBBFJR@DCDCBGACOCAODAMEECCEAICUECCGKBMEGHIGIUDE@EC@CBISBGGMAEKGE@IACG@ADEBG@ICCC@EDGHBNBFGBEGIEAWDSPDJCFA@ICAECI@QACM@IKIAAJ@NCFCCEKGGACAIDGACCAC@@BAJCH@LIJDVMBCNM@E@KTSBMFGDORODIFCDCBGEC@GDEHOJGBGCWPEAABBFALDH@FDHJHLDDHRDDDRFBFFBH\\FHPFJ@PJRFHATND@JDHA@FILBFAH@DDDNEB@BBARAFHRCHBFDBHGF@DHHD@FFHEDBBJBBHLBJJH@DDDCB@DDBHJH@DPJ@LBBLANFF@@HLLRFJFF@@DCHBFFRHF@HDJ@DGH@FN@BBA@IBBBND@BCD@DLBJD@@BBADBFCD@BGFAFGFBDGBABKDGAACEfHt`fXJFHNH@BCFEJIDAD@FC@GFALEAEBGH@DGAEBG@CDBDKFE@QCEBCAG@EEEBCBIAIDIDM@EAGDAVELADBDETBNFLNFCFN@DAPMDBDDHDVBHHFJFFDABDBJ@HCTQFELK@KDIPILAF@DEFBDJDBDCBCDALENBNBD@DCB@FBBKJCH¹[G@KHC@KGCEA@SJEBECEBKEGBQCIBICIAKGAHHHABE@ADBFJN@HFFHNJLDPDDFTBFA\\DHCPHJ@NDT@RFRAN@PFRBJAJLTADCFADBJFFADCX@JDJCL@FBFJFBD@DCFGB@PBLCJ@TELBHHTCJBJADCBCHABK@IDGH@JABVXHBDFBNLLTBJAJ@FBHJJBL@PDD@DBBFLHXJLDFDD@BAD@NRLTHHD@ABLLHLFBDAB@RHNN@HBBFGLI^EH@BC@GDBDAHFJBPENAJDFEVJDDFJNFTNBDABFNEFKBABAFBLGDCNGBKHEBGAEEEAIFILKFCFIPCFCDKF@X"],"encodeOffsets":[[100076,25519]]},"properties":{"cp":[98.578363,24.436694],"name":"德宏傣族景颇族自治州","childNum":1}},{"id":"533300","type":"Feature","geometry":{"type":"Polygon","coordinates":["@@NGBCBKEIBGFMBGDAHCDCDADELEBE@GBIEOEEBKBCBCNAR]HGRANEAMJSHKJIBKDILG@GCAGGEABELCDCBGAMBMAOGSE[HGNABAFKHGBC@CEGDEBMCYPS@CMWNOHCVDJA\\A@FFHDHDDVHZT@HGJADDFLFBDBBH@FBH@D@FCFBROFCDAJBLFHFFPRRBLDBVLTDZJPEJARFH@BARGDCFCDBXKF@@ANAHAHHDTBBBFHFDHTVJ@HDJLdA^PDACYEGIIEGHIJWBMPABAAMDgNCBADMJ@LBDABIAMLW@Q`BHEBEBGHKDQ@AA@IHG@GEBIBAJCR@DC@GDEFAV@BCBEFIHI@SBCJAIU@GBKDG@KBADOCGC[CMBaEIAIBEFEEICYFKCO@ABEFEBMBMJIHADAAKDIIKAIBADAHKHCFGDGDCLCD@HDPRFDFBJADCDC@EEUAW\\]BGCMFQAEDEHCFGDK@KDGAGIOMI_GUKCEBIJWRKPUDARBVWRIJIHKJKHCDMHEDC@KDCH@DC@AMMCIOQAQKEGGEICQKGAI@CDANCFE@CCSF@NKBGDADGDQFKCCIICSMUCKFGF@FEFIHIBGHGAQ@CFK@MDKCQBKGKEOKU@GBGJKHCH@@CBMDGHI@IAKBQIQBADAZDJLB@LGD@HDDAFEFING^LD@NCHDBAB@DKLMH]BSCcCAE@OEGGCE@OBCHEBECIEGF_EYKSUIGE@CBIFECGIECMFMNADET@BA@IGK@C@EBMIM@C@OBKAI@EFGAKISIEAEBGHOX[@A@CEEAEDCLCJGNER@VJH@ACKI@KCG@CIDK@IDCAG]JIDYDAF@FBD@LHBABEDCJCTARIF@VHDDD@\\CFFRDFDFJHFNJ\\UJETBPHTDHG@EDIHDPBPAFCDBJCD@DAJADCF@DAVEFBFABFFADBDBHDFBJHJDDFDBBHHLFDPBZ\\@H@FILMfMVBNDB^DLEP@B@JIH@DCFQPKLWLQBKHOJYDCPMPWDECKLI@CEGRMDGACECCE@EFITODIFG@AEOAEDGHBLH\\NHD^LLFEBQFIDIHKTDDTDPdFFPMDMFELLZLHAVMfFXBHIJeLGNMBMV]HC`D\\MFEAGCG@IBCEEAEHM@KFOJIRBBCAGIIAIBECCEACBMDGDCCAEDCTEH@VFHABACGBEBEMIFEAGGI@KFQP[NkDUT_AUDSBErOLKVY]QCECKDUEI@SGOKKE@MAQHMII@SQmQWMKEGAaKm[@ABIAOJMJKFSAIDaGOHMBOCKIG@GBATIHGDG@KBGJKEQEKEOOCBKMAGECIQQAA@ECMYUMAGEAIECCKOIIAGCDIMKM@KBCD[AC@EHSAEABKQGEKcOCCCGGKE@A@CNKBGDMECBAAEGAQICQ[E_@EBEFCNEPCJE@AAEEIQEAKAEU@GEEI[DOBYUG@MDKBACCMACKEEGUAGCEIUGCECMGEIACAQQIO]IBETYBECIBCJKTOR@VGAGGKCAG@GBIFINQDEFMFQ@[PGFWGCGQBI@ECEHQBEBADDBPAD@DX@FCD}@SFYFCAEEEBA@OOICDK@IECOKCKICGIEQBEHG@CGIDIAEAKACE@ACAK@GHQAOBI@ADCFAFIAMBC@IBC@GCCIECGFUDiDKAI@GHBDBLBDARGJBdNHFDAHGFKDCLUZoFMH]BYPYNgNYH[FINkRaCCEAGFKAaDQ@[GYIC@EJK`AJBDLHBDGFUDG@KEMJIDGACAAIBGDEBG@OGGKIAAHAJIFSFENKNGJ_CAKBM@QFAAAOEGIAI@YIQDSFKDKJMAKRCDSJEHEBCGIACBGFGDUDCDCHBVCFCDE@OEGAg@C@IOAM@GBCHABCDIBGBCLCVCGQUMBKFOAKCKEC@SBILADEA]BEHAFCDE@WAIEGIACDGBE@IEDOBEFGLCPKBEAKGIKK@EHK@IKSK@AAAO@EDG@AKDIAGDG@S@[HaDKAWOIAIBIBSDED@VA@G@C@INEL@FP|L\\BHADADMLADDRCP@FR\\DRAFQPCHADGDIF@HBBNN@DANCJBFEFYL@BDPCH@DP`MFMBIHIHMdGF@DDFNF@FJFFVBFBFCFMLCNCJIDI@CPDHBFCRELBPCFKNGHCBET@RKRCBOLKRIJMBKDCTEDKBOC]AAZAJGLDHCLBFEF@D@FD@BDCDEDCNCFBXANBL@DQb@BGCQ@DH@HHDBHCJ@LINIb@DNJFN@FCLFBHC\\URJBDHFNDFJD@JBbGJCJIDG@GHMBIEKCEECCK@GFKDCF@FDFHDDJBFBNLFLFDHBHABHRJRPANCHADIDCDAFBHBFDDFBRBHFHLFVBPAFMNEHAHBJCLOTCPGFGJMDOOIFYHBLN`@LGP@HDJNR@FEFCTFAp`DFDHFHDFLDJLLLCRCFALDL@FHHLDFFBPAPJHCL@HBDFDDHADOLCHLVAXLTAXLTBHCPIJAH@FHHBJ@RAHDPCfBFHJFDNDNXHVDPET@DHJ@FIRILG^KVBHJHEPBFHHBNEBS@WJAPCPHVBHJNANJLA^FL@^@LFN@JGVGHGREHQRGJGVFNFDFHHFNHFFFHBJCN@NAHCVARBHMLCFDTADCJ@JIHCN@JJXDRGPABIB@HRPDFfJDR@LFL@DADAFBHADKFQNELMJE@MGGAOFGJEB@JFZCJEH@H@HBDFFALGR@HBFHHGN@PGR@TCJ@HEJONCJBFF@@RFFBBJ@FHTBLD@LKJFFHPDBFADFCFQFGHADDL@N@DHDJBHNJLETFJDPDJBLADDL@DQN@B@NHHABCBG@SDEDEJKDABKfHD@DATCNBVCDGBEFAFGBCF@NHFCF@DAHDFDBJDLADF@V@BOLAJKHAFGJRdAFGFDHFDTBDBEVGPBVNNAHCHCBMCMDGHGJKVIHIBIAKIAC@OGIECA@GHcPE@OAC@IHIAGEAEDGA@MCEBABEHBNFRKPADAJQ\\CNELCPCHEHEDIACC@GUEAACKBKAC@AQAOLWAABBJCDK@SFIAGBKAMHKNGTABQJIJA@G@MEAEAG@CHKAQJKBEAOKKACCEHKAMEMFMB]AOBEEI@IACOAQAUKEQEECMGIQKMECAOBQJIBKEECI@UPQFCDBJBDAJADMPEV@PFJ@XBJOZCTCJ@F@LHN@DEFCDS@CLAXCHKLMCEACBBNCLEDADCDOFEFQJGDABBLEPGHMDABDHDDDFCD@FNFBHL@PHCPABQJSDMVAHDHALFLBJHR@BADAJBLAD@BOAIBWRmXGNBHGPBBLJEHBBDDD@BB@JDF`@HDBB@THHIN@NM\\@LKP@RQBYEWDSRIHG`@TGNBNPJ@NCNHHDJAJEJATCH\\bBHDTJVBJAFBVEFIHGJDNGLObRNDJ@DHAHBFLDBD@HCD@HFBHAJILBPAP@V@BVRJBN@THF@DABC@ELCHBV\\LBRN\\HRDDF@HGLMJBHEH@HKHGH@NGF@PG^ILkZGJENBRBJFJF@JAVQDABB@JDRFPLBJJHDNALBRDDBFFJVH@FCHBDE"],"encodeOffsets":[[100653,29072]]},"properties":{"cp":[98.854304,25.850949],"name":"怒江傈僳族自治州","childNum":1}},{"id":"533400","type":"Feature","geometry":{"type":"Polygon","coordinates":["@@EIBKBAJIBCBGMSBGAGBKAKCCCBCACIDCLEDEBMACGCCIDIHE@ICGBIAOJO@ACIBKEcDGF]@kJIHQ@QI]DQ@MHI@EEMAQHEHIEICGCQJ]AOCI@KGOGEKEDM@GAGKSCUEMBEDCAUBI@CEKFIF[P_E[@GDCFOJGLOJQ@IEIACFO@EGKGGBEBEVSFI@ECK@GLKDEEUBGBCDA\\GBCBEIIAGBCNCDAHGBIOOAA@EDADAVCHEBAAEEIEIAIKMBM@AF@DG@AGI@CDEDMFG@GDKAE@EDEHEFEFU@GEEAOIUBE@cFUIKUEGECEFGDAHGDKCMDENGNUFGPIDECO@CDAH@LEDKFCNCH@DA@WLQ@ODGVIVSlIJIHOAUCIEACCAKBADCHAHBJFFABCCILKDEBKAQBCLGNCBCAGBCH@HHFAFODAHAJEFEDC@KPKDIBCFALDH@DANOHCLK@A@KDEPIFD@HGJEF@HILALEBADBHABBDEZBPNhBRVj@FJFDBDAD@BD@PATCHAHAFEFKDMZGLFDVJDLAT@TCFBFFFRJDHBZDJTNHL@FAPILIBS@EHOZAVTJVFDDOJCTCBCPEJGHOHEFBV@JBDHBBDELIJPNDD@HCRLJF@JCDBHHJDZ@BAFGDALDL@LCBDARBBFJET@DDDNLPNXJFFBFAR@FBDPFF@FAPIL@JBJHBDLFDFELFTAV@DDHBF@LCFCFQJ@DLJFDDFLHFNFTJFDHFAHEB@~XFFDD@DEFDBPDHFBDADMTFRABGPFTDHXTBDBFATBFBDRCH@NFXC^@DADCDANDJDDD@DHNFNFHLDNBDLFDBC@QBIBQDMBGES@EDGB[Cc@KFKJOJGDIEQAG@E`MLMDIhARCRDBA@EDCLADCNMLILOJCDCNOJC@I@AECGKBCNABAIGGK@CV@JDLHHBXCDC@E@EAEHIAKDCLGL@LEJ@FAH@HGPBDABGXKHIDEPADAJKAQDGH@FDBCBEBE@YBEJGPBJEFKDM@O@EKKBAFGDEBEAGFM@IFINMVCRIHANMB@JDHAJKRBJBD@BKFOHGLIEIU]@AJC@CWqBKBABALDF@NEhEFAJGNAVIHDJCFCJ@FG@IDEVCNKDGDAJDFAJAFEGGGqEAUAICCGBILMFCRAFAJQVMFG@ACCKGOQOCACLQ@AAESSIEGAaASEU@SCGG@CBEKGCMGCCDM@EJKDMJC@WWG@IDOBEGDKBCSYAGBMEEDEAABAFCBEFA@CD@BCH@FCFEBE@E@A@AB@AALQ@CFCFMBA@IDGBABEJOAEBC@AB@BIDAACFGAEDADEBEDCACDIJGHMFCF@LED@DAF@FCPCDCHAJIT_FEHEJADC@ELKDELIBCJIFCD@JMLCDAFG@CDA@IHI@CIGSUEKQMAM@GDAJDJ@F@JKNCDGJCLKFAH@DBLA\\OZ@FANGPHLBXIVJFAJIJADC@CCIIKHEAIHKAGECEAYUEIAKDIJIVGBC@QEWHODO@KKOCICACK@MAKAKUMG[DEVGBAD[DICCOKACAI@GECM@CIAQEAK@CACEAKJSFOAEMEQAQC@IBIBI@OFQACMQaOCEAKKOIIOGOQEKCMEQCGICACBOHGDGV[FMLQDGFaHGDECIKQLOLMJMLKHOBI@QDGCQ@CJCBA@YEG@GCAOEO@ICOAMIGSSQAGGAM]ECGAGCWSAIGEOWGMACOMKQAIGIIGGOIEE@gIECQGECAECKE]EuBIDEFEFOB_FGJCDIBQFO@EOOEK@EDGNIBE@ICMEKOWEQCI@MESFc@GAG@ACAKBCACAKQ@EACGGBOEGGCQCYUWECCCIK@MCOOEAIBGJAHBFHLAPEJSR@BDJJNBH@NEHDLALCHGNDDBBJDNB@HCHMPGFGF@NANWVIFGH@@DLINENEHQJURCFAFBX@FCF_VEDE@MAE@EDGHQlCL@NSJINGHCHEJABYHOJGLARAPADGD[HCDAPEHEBaDQLQ`EFMHGHALADWBGBCDAFAPCFOHWNADBDCHEBK@KDAFDXADGFMDIFEFCJ@FFXAHBD^RBFW\\KXEDcRKHAHBPENGJOLKJBFHL@LBBHFBDBFCHCDMDMGEBEH@HCFOLKDADAN@NIJAH@FDPHNDX@FEFCAGBOPADFR@LCPKHE@BMACaMKICA_GCAAGDIBEKU@CDOAAW_KCOAICUEOAQFYO[AEEAG@EBEJMCKHMAAEAIIGU@EBCJGBEJMDGBOGW@CDI@KHENAAIBGFEJCDC@EFC@CQOKMAICEAIIMCKCIKCK@CGAEAOBOP_NeLW@CCAYCMIEECCGCIAAABADA@IBCLE@CBCF@JCD@LEDCIQ@G@CLEJICQBEDCV@DAHIAkBELEBC@M@AKFMBIAAA@EBEPGBK@CIiDUDILAD]@GDCXWVILANsJEFKHAFGAEFUAMEHI@sGUNGBYKKKEFCNKLA@C@CCOcSCCCLSJGJCREFAKE]KGC[MKGGACHBFFP@BEHCJSPEJ@FDFFDBDCHQNFH@DKJDLCFOXONCDIZGPALKRKXOLERCDG@EFEDO@KF]CCAAMNUNeJK@E@GY[OAECGKAGCACEICIGEAGCCACACBAAACQBODCBE@CDIBCBC@GDEAEDMBOAEACACJ@FGHSCOGSAIF[VMIGEEIECQCEE[DSIMAQJUBIDCDAFABKGC@EAE@CBCZIJH^DBJCL@JC@DDH@LLJBDG@UIQ@MFKJIBCD@DDFDB@D@BSXMXBJJFDHFTBDEH@FBJAL@P@DJNAN@F@DHL@JABS@CFMBEN@DDJJFDHEFAJ@DHFVJLTFZE`FHDJAFGFAD@PDFHHPFF@DBDdAZGXKNCLA@ABGCMDC@]KMHEJEFCBGCC@KHA@IKYCCBABJRARBL@JGJCHAN@DG@GDILAH@HLVFPHLALDRCL@NEL@DBRGHAHGJEJEFE@EHDLNVDTJJDDELCRCHCBAHMLE@DT@DEFMDCB@DBJLHDRFJHHLFBRPRDJNN@BCDG@CD@LCDGFCNGDILGLIJQJUXQASXQLENETDFVL`HNJJPBHCH@LCLEHGDCFBFERDNAH[^BXFV@FCDCDIBEAECOQGCC@KDCDCHEHGDGLCBABBJJLCJBLCBGBIJANANEFAF@BDPELDZFJEFAFBJFJAbDND\\DHCPAB@LCHAL@HJVKB@XGJGREBQ@EBCF@HCDQ@IDABAJHFH@JGB@@BCRGLAHAFGF_A@RKXBNAJCBKAI@CNABMDChBNABOBANIXGJFHJJFHDZCBDFAJDD\\HAHDLCRBHERJXDH@BKR@FDLFVHJJFJDXFLFNbEFMLIJGRBJCHGHSNATIDQB@BDHDH@LAFYhEFOF@DHHBDYjGTBLSAOHUHKBU@CBEJIV@LDHHHDPLNBD@FADAFBLJJSHCD@BFDFLCJKLCJCH@BHJBBADKLALGJLHBH@FADCDCHADGFENCLDNOJKP@DDJCN@DV@TCFBZHFDFJDP\\HPJNFNLNVDDAB@F@HFDCJBJ@DCDIBADBNFP@DCDCDGBAJABGBEDANCJBDDB@HCBICA@CLAJDLBFHFBB@PJJHDABSNGNCHAL@LELAHAD@FCLBFBBLFHNBHCBK@AD@DLPFFBFEBMAEFGPEBIACF@DJJAJ@BEBQDAHBDNDBDAHNBHAJDN@FDBANAJGD@HAJ@LCFBFEPAHAJBFDBDJDBLJHTFJLRBFDRXTDDAHKZADAAADCBGACEA@ABCHCJG@EHGJEDKBIRS@IGUAIBCFCPG@AECACAgFKJEFKICAC@G@OHIBEQOB@NCDCBC@KCIBGAOJILEFCAMBCXINDJLPDNA\\EHIH@LDHADBHHJBBBDRCNPPF@HEHAP@FFFDH@JINDDD@HGR@DELLJDHBJCFKNUEGA_RMFGDMFAB@LCPGPLLDH@RDPDLETBFHPBFATBFNNZAJBDDBHHLHR^XLBFBFHHFRFJ@HDFJFN@TGVIR@LIXCDGRGJQHCDI\\CDE@GDAPELANAjBJ@BRHFD@fDJL@^EHETCHEJIFADBFTBDJJJDTBbDV@LLNBFDDHlC"],"encodeOffsets":[[101493,29923]]},"properties":{"cp":[99.706463,27.826853],"name":"迪庆藏族自治州","childNum":1}}],"UTF8Encoding":true});
}));